@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/calma/CalmaRdcl.c,v 1.3 2010/03/08 13:33:33 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/calma/CalmaRdcl.c,v 1.5 2010/06/25 13:59:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -341,15 +341,8 @@ calmaParseStructure(filename)
 	if (nsrefs > osrefs && (nsrefs % 100) == 0)
 	    TxPrintf("    %d uses\n", nsrefs);
 	osrefs = nsrefs;
-#ifdef NONMANHATTAN
 	calmaNonManhattan = 0;
     }
-#else
-    }
-    if (calmaNonManhattan)
-	TxPrintf("    %d non-Manhattan paths converted to stair-steps.\n",
-		calmaNonManhattan);
-#endif
 
     /* Make sure it ends with an ENDSTR record */
     if (!calmaSkipExact(CALMA_ENDSTR)) goto syntaxerror;
@@ -903,7 +896,8 @@ gdsCopyPaintFunc(tile, gdsCopyRec)
     else
 	TiToRect(tile, &targetRect);
 
-    DBPaintPlane(plane, &targetRect, CIFPaintTable, (PaintUndoInfo *)NULL);
+    DBNMPaintPlane(plane, TiGetTypeExact(tile), &targetRect, CIFPaintTable,
+		(PaintUndoInfo *)NULL);
     
     return 0;
 }
