@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/calma/CalmaRdpt.c,v 1.5 2008/12/20 05:02:46 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/calma/CalmaRdpt.c,v 1.7 2010/08/25 17:33:54 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -49,10 +49,8 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 
 extern int calmaNonManhattan;
 
-#ifdef NONMANHATTAN
 extern int CalmaPolygonCount;
 extern HashTable calmaDefInitHash;
-#endif
 
 extern void calmaLayerError();
 bool calmaReadPath();
@@ -207,9 +205,7 @@ calmaElementBoundary()
     LinkedRect *rp;
     Plane *plane;
     CellUse *use;
-#ifdef NONMANHATTAN
     CellDef *savedef, *newdef = NULL;
-#endif
 
     /* Skip CALMA_ELFLAGS, CALMA_PLEX */
     calmaSkipSet(calmaElementIgnore);
@@ -246,7 +242,6 @@ calmaElementBoundary()
 
     /* Convert the polygon to rectangles. */
 
-#ifdef NONMANHATTAN
     if (CalmaSubcellPolygons && (calmaNonManhattan > 0))
     {
 	/* Place the polygon in its own subcell */
@@ -276,19 +271,8 @@ calmaElementBoundary()
     }
 
     rp = CIFPolyToRects(pathheadp, plane, CIFPaintTable, (PaintUndoInfo *)NULL);
-#else
-    rp = CIFPolyToRects(pathheadp);
-#endif
     CIFFreePath(pathheadp);
 
-#ifndef NONMANHATTAN
-    /* The non-Manhattan geometry polygon parsing algorithm */
-    /* typically leaves behind degenerate paths, so they    */
-    /* should not be considered erroneous.                  */
-    if (rp == NULL)
-	calmaReadError("Can't convert boundary/box into rects; ignored.\n");
-#endif
-
     /* Paint the rectangles (if any) */
     for (; rp != NULL ; rp = rp->r_next)
     {
@@ -297,7 +281,6 @@ calmaElementBoundary()
 	freeMagic((char *) rp);
     }
 
-#ifdef NONMANHATTAN
     if (cifCurReadPlanes == cifEditCellPlanes)
     {
 	CIFPaintCurrent();
@@ -315,7 +298,6 @@ calmaElementBoundary()
 	DBSetTrans(use, &GeoIdentityTransform);
 	DBPlaceCell(use, cifReadCellDef);
     }
-#endif
 }
 
 /*
@@ -444,10 +426,8 @@ calmaElementPath()
     Rect segment;
     Plane *plane;
     int first,last;
-#ifdef NONMANHATTAN
     CellUse *use;
     CellDef *savedef, *newdef = NULL;
-#endif
 
     /* Skip CALMA_ELFLAGS, CALMA_PLEX */
     calmaSkipSet(calmaElementIgnore);
@@ -587,7 +567,6 @@ calmaElementPath()
     {
 	plane = cifCurReadPlanes[ciftype];
 
-#ifdef NONMANHATTAN
 	if (CalmaSubcellPolygons && (calmaNonManhattan > 0))
 	{
 	    /* Place the polygon in its own subcell */
@@ -615,13 +594,11 @@ calmaElementPath()
 		    plane = cifCurReadPlanes[ciftype];
 	    }
 	}
-#endif /* NONMANHATTAN */
 
 	CIFPaintWirePath(pathheadp, width,
 		(pathtype == CALMAPATH_SQUAREFLUSH) ? FALSE : TRUE,
 		plane, CIFPaintTable, (PaintUndoInfo *)NULL);
 
-#ifdef NONMANHATTAN
 	if (cifCurReadPlanes == cifEditCellPlanes)
 	{
 	    CIFPaintCurrent();
@@ -639,7 +616,6 @@ calmaElementPath()
 	    DBSetTrans(use, &GeoIdentityTransform);
 	    DBPlaceCell(use, cifReadCellDef);
 	}
-#endif /* NONMANHATTAN */
     }
 }
 
@@ -833,11 +809,19 @@ calmaElementText()
     /* Place the label */
     if (type >= 0)
     {
+	int flags;
+
+	if (cifnum >= 0 && (cifCurReadStyle->crs_layers[cifnum]->crl_flags
+			& CIFR_TEXTLABELS))
+	    flags = LABEL_STICKY;
+	else
+	    flags = 0;
+
 	if (font < 0)
-	    DBPutLabel(cifReadCellDef, &r, pos, textbody, type, 0);
+	    DBPutLabel(cifReadCellDef, &r, pos, textbody, type, flags);
 	else
 	    DBPutFontLabel(cifReadCellDef, &r, font, size, angle,
-			&GeoOrigin, pos, textbody, type, 0);
+			&GeoOrigin, pos, textbody, type, flags);
     }
 
     /* done with textbody */
@@ -948,12 +932,6 @@ calmaReadPath(pathheadpp, iscale)
 	    pathtailp = newpathp;
 	}
     }
-
-#ifndef NONMANHATTAN
-    if (nonManhattan && (iscale != 0))
-	CIFMakeManhattanPath(*pathheadpp);
-#endif
-
     return (*pathheadpp != NULL);
 }
 
