@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) ="$Header: /usr/cvsroot/magic-8.0/calma/CalmaWrite.c,v 1.6 2008/12/20 05:02:46 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) ="$Header: /usr/cvsroot/magic-8.0/calma/CalmaWrite.c,v 1.7 2010/06/24 12:37:15 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -1696,7 +1696,6 @@ calmaMergePaintFunc(tile, cos)
 	if (t->ti_client != (ClientData)GDS_PENDING) continue;
 	t->ti_client = (ClientData)GDS_PROCESSED;
 
-#ifdef NONMANHATTAN
 	split_type = -1;
 	if (IsSplit(t))
 	{
@@ -1721,7 +1720,6 @@ calmaMergePaintFunc(tile, cos)
 	    }
 	}
 	else
-#endif
 	    num_points = 3;
 
 	/* Create a new linked boundary structure with 4 unknown edges.	*/
@@ -1754,7 +1752,6 @@ calmaMergePaintFunc(tile, cos)
 	/* Initialize the "edge" record with the corner points of the	*/
 	/* tile.							*/
 
-#ifdef NONMANHATTAN
 	if (IsSplit(t))
 	{
 	    switch (split_type)
@@ -1820,7 +1817,6 @@ calmaMergePaintFunc(tile, cos)
 	}
 	else
 	{
-#endif
 	    lb->lb_start.p_x = urx;
 	    lb->lb_start.p_y = ury;
 	    lb->lb_type = LB_INIT;
@@ -1839,23 +1835,18 @@ calmaMergePaintFunc(tile, cos)
 	    lb = lb->lb_next;
 
 	    num_points = 0;
-
-#ifdef NONMANHATTAN
 	}
 	if (split_type == 0x1) goto left_search;
-#endif
 
 	/* Search the tile boundary for connected and unconnected tiles.	*/
 	/* Generate segments in a counterclockwise cycle.			*/
 
-#ifdef NONMANHATTAN
 	if (split_type == 0x2)
 	{
 	    intedges += calmaAddSegment(&lb, TRUE, RIGHT(t), TOP(t),
 			LEFT(t), BOTTOM(t));
 	    goto bottom_search;
 	}
-#endif
 
 	/* Search top */
 
@@ -1869,14 +1860,12 @@ calmaMergePaintFunc(tile, cos)
 	    if (!is_ext) PUSHTILE(tp);
 	}
 
-#ifdef NONMANHATTAN
 	if (split_type == 0x3)
 	{
 	    intedges += calmaAddSegment(&lb, TRUE, LEFT(t), TOP(t),
 			RIGHT(t), BOTTOM(t));
 	    goto right_search;
 	}
-#endif
 
 	/* Search left */
 
@@ -1891,14 +1880,12 @@ left_search:
 	    if (!is_ext) PUSHTILE(tp);
 	}
 
-#ifdef NONMANHATTAN
 	if (split_type == 0x0)
 	{
 	    intedges += calmaAddSegment(&lb, TRUE, LEFT(t), BOTTOM(t),
 			RIGHT(t), TOP(t));
 	    goto done_searches;
 	}
-#endif
 
 	/* Search bottom */
 
@@ -1913,14 +1900,12 @@ bottom_search:
 	    if (!is_ext) PUSHTILE(tp);
 	}
 
-#ifdef NONMANHATTAN
 	if (split_type == 0x1)
 	{
 	    intedges += calmaAddSegment(&lb, TRUE, RIGHT(t), BOTTOM(t),
 			LEFT(t), TOP(t));
 	    goto done_searches;
 	}
-#endif
 	/* Search right */
 
 right_search:
@@ -2033,8 +2018,6 @@ calmaWritePaintFunc(tile, cos)
     calmaOutRH(6, CALMA_DATATYPE, CALMA_I2, f);
     calmaOutI2(calmaPaintLayerType, f);
 
-#ifdef NONMANHATTAN
-
     /* The inefficient use of CALMA_BOUNDARY for rectangles actually	*/
     /* makes it easy to implement triangles, since they must be defined */
     /* by CALMA_BOUNDARY.						*/
@@ -2074,19 +2057,14 @@ calmaWritePaintFunc(tile, cos)
     }
     else
     {
-#endif
-
-    /* Coordinates */
-    calmaOutRH(44, CALMA_XY, CALMA_I4, f);
-    calmaOutI4(r.r_xbot, f); calmaOutI4(r.r_ybot, f);
-    calmaOutI4(r.r_xtop, f); calmaOutI4(r.r_ybot, f);
-    calmaOutI4(r.r_xtop, f); calmaOutI4(r.r_ytop, f);
-    calmaOutI4(r.r_xbot, f); calmaOutI4(r.r_ytop, f);
-    calmaOutI4(r.r_xbot, f); calmaOutI4(r.r_ybot, f);
-
-#ifdef NONMANHATTAN
+	/* Coordinates */
+	calmaOutRH(44, CALMA_XY, CALMA_I4, f);
+	calmaOutI4(r.r_xbot, f); calmaOutI4(r.r_ybot, f);
+	calmaOutI4(r.r_xtop, f); calmaOutI4(r.r_ybot, f);
+	calmaOutI4(r.r_xtop, f); calmaOutI4(r.r_ytop, f);
+	calmaOutI4(r.r_xbot, f); calmaOutI4(r.r_ytop, f);
+	calmaOutI4(r.r_xbot, f); calmaOutI4(r.r_ybot, f);
     }
-#endif
 
     /* End of element */
     calmaOutRH(4, CALMA_ENDEL, CALMA_NODATA, f);
