@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cif/CIFrdtech.c,v 1.2 2009/05/03 15:01:04 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cif/CIFrdtech.c,v 1.3 2010/08/25 17:33:55 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -770,13 +770,26 @@ CIFReadTechLine(sectionName, argc, argv)
 	    TechError("Must define layer before giving labels it holds.\n");
 	    goto errorReturn;
 	}
-	if (argc != 2) goto wrongNumArgs;
+	if (argc != 2)
+	{
+	    if (argc == 3)
+	    {
+		if (strcmp(argv[2], "text"))
+		    goto wrongNumArgs;
+	    }
+	    else
+		goto wrongNumArgs;
+	}
 	CIFParseReadLayers(argv[1], &mask);
 	for (i=0; i<MAXCIFRLAYERS; i+=1)
 	{
 	    if (TTMaskHasType(&mask,i))
+	    {
 		cifCurReadStyle->crs_labelLayer[i]
 			= cifCurReadLayer->crl_magicType;
+		if (argc == 3)
+		    cifCurReadStyle->crs_layers[i]->crl_flags |= CIFR_TEXTLABELS;
+	    }
 	}
 	return TRUE;
     }
