@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdCD.c,v 1.5 2009/09/11 16:09:49 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdCD.c,v 1.7 2010/06/24 12:37:15 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -48,10 +48,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #include "utils/signals.h"
 #include "utils/malloc.h"
 #include "cif/CIFint.h"
-
-#ifdef NONMANHATTAN
 #include "cif/CIFread.h"
-#endif
 
 /* The following structure is used by CmdCorner to keep track of
  * areas to be filled.
@@ -104,9 +101,7 @@ bool cmdDumpParseArgs();
 #define CALMA_RESCALE	10
 #define CALMA_WARNING	11
 #define CALMA_WRITE	12
-#ifdef NONMANHATTAN
 #define CALMA_POLYS	13
-#endif
 
 #define CALMA_WARN_HELP CIF_WARN_END	/* undefined by CIF module */
 
@@ -141,10 +136,10 @@ CmdCalma(w, cmd)
 	"warning [option]	set warning information level",
 	"write file		output Calma GDS-II format to \"file\"\n"
 	"		for the window's root cell",
-#ifdef NONMANHATTAN
 	"polygon subcells [yes|no]\n"
 	"		put non-Manhattan polygons into subcells",
-#endif
+	"unfracture tiles[yes|no]\n"
+	"		optimize tiling of non-Manhattan geometry",
 	NULL
     };
 
@@ -356,7 +351,6 @@ CmdCalma(w, cmd)
 	    CalmaMergeTiles = (option < 3) ? FALSE : TRUE;
 	    return;
 
-#ifdef NONMANHATTAN
 	case CALMA_POLYS:
 	    if (cmd->tx_argc == 3)
 	    {
@@ -378,7 +372,6 @@ CmdCalma(w, cmd)
 		goto wrongNumArgs;
 	    CalmaSubcellPolygons = (option < 3) ? FALSE : TRUE;
 	    return;
-#endif  /* NONMANHATTAN */
 
 	case CALMA_READONLY:
 	    if (cmd->tx_argc == 2)
@@ -886,9 +879,8 @@ badusage:
 #define WARNING		16
 #define CIF_WRITE	17
 #define CIF_WRITE_FLAT	18
-#ifdef NONMANHATTAN
 #define POLYGONS	19
-#endif
+#define UNFRACTURE	20
 
 #define CIF_WARN_HELP  CIF_WARN_END	/* undefined by CIF module */
 
@@ -939,10 +931,10 @@ CmdCif(w, cmd)
 	"write file		output CIF for the window's root cell to \"file\"",
 	"flat file		output flattened CIF for "
 				"the window's root cell to \"file\"",
-#ifdef NONMANHATTAN
 	"polygon subcells [yes|no]\n"
 	"			put non-Manhattan polygons in subcells",
-#endif
+	"unfracture [yes|no]\n"
+	"			optimize non-Manhattan geometry",
 	NULL
     };
 
@@ -975,9 +967,7 @@ CmdCif(w, cmd)
     {
 	case HELP: case ISTYLE: case OSTYLE: case PREFIX:
 	case AREALABELS: case WARNING: case CIF_LIMIT:
-#ifdef NONMANHATTAN
 	case POLYGONS:
-#endif
 	   break;
 	default:
 	    windCheckOnlyWindow(&w, DBWclientID);
@@ -1170,7 +1160,6 @@ CmdCif(w, cmd)
 	    else goto wrongNumArgs;
 	    return;
 
-#ifdef NONMANHATTAN
 	case POLYGONS:
 	    if (argc == 3)
 	    {
@@ -1192,7 +1181,28 @@ CmdCif(w, cmd)
 		goto wrongNumArgs;
 	    CIFSubcellPolygons = yesno;
 	    return;
-#endif  /* NONMANHATTAN */
+
+	case UNFRACTURE:
+	    if (argc == 3)
+	    {
+#ifdef MAGIC_WRAPPER
+		Tcl_SetObjResult(magicinterp, Tcl_NewBooleanObj(CIFUnfracture));
+#else
+		if (CIFUnfracture)
+		    TxPrintf("Non-manhattan geometry optimized.\n");
+		else
+		    TxPrintf("Non-manhattan geometry not optimized.\n");
+#endif
+		return;
+	    }
+	    else if (argc != 4)
+		goto wrongNumArgs;
+
+	    yesno = Lookup(argv[3], cmdCifYesNo);
+	    if (yesno < 0)
+		goto wrongNumArgs;
+	    CIFUnfracture = yesno;
+	    return;
 
 	case PREFIX:
 	    if (argc == 2)
@@ -1833,7 +1843,6 @@ int cmdCornerDir2;			/* Second direction each wire must
 Rect cmdCornerRootBox;			/* Root coords of box. */
 struct cmdCornerArea *cmdCornerList;	/* List of areas to fill. */
 
-#ifdef NONMANHATTAN
 typedef struct cifpathlist
 {
     TileType pathtype;
@@ -1847,8 +1856,6 @@ typedef struct nmcornerpath
     CIFPathList *pathlist;
 } NMCornerPath;
 
-#endif
-
 void
 CmdCorner(w, cmd)
     MagWindow *w;	/* Window in which command was invoked. */
@@ -1861,7 +1868,6 @@ CmdCorner(w, cmd)
     bool hasErr = FALSE;
     int locargc = cmd->tx_argc;
 
-#ifdef NONMANHATTAN
     extern int cmdBevelFunc();
     bool dobevel = FALSE;
     NMCornerPath cmdPathList;
@@ -1870,11 +1876,6 @@ CmdCorner(w, cmd)
     {
 	TxError("Usage: %s direction1 direction2 [layers]\n",
 			cmd->tx_argv[0]);
-#else
-    if (cmd->tx_argc < 3 || cmd->tx_argc > 4)
-    {
-	TxError("Usage: %s direction1 direction2 [layers]\n", cmd->tx_argv[0]);
-#endif
 	return;
     }
 
@@ -1912,7 +1913,6 @@ CmdCorner(w, cmd)
 	}
     }
 
-#ifdef NONMANHATTAN
     /* Check for "bevel" keyword */
 
     if (locargc > 3)
@@ -1923,7 +1923,6 @@ CmdCorner(w, cmd)
 	    dobevel = TRUE;
 	}
     }
-#endif  /* NONMANHATTAN */
 
     /* Figure out which layers to fill. */
 
@@ -1964,7 +1963,6 @@ CmdCorner(w, cmd)
     scx.scx_use = (CellUse *) w->w_surfaceID;
     scx.scx_trans = GeoIdentityTransform;
 
-#ifdef NONMANHATTAN
     if (dobevel)
     {
 	cmdPathList.hasErr = FALSE;
@@ -2006,32 +2004,28 @@ CmdCorner(w, cmd)
     }
     else
     {
-#endif
 
-    cmdCornerList = (struct cmdCornerArea *) NULL;
+	cmdCornerList = (struct cmdCornerArea *) NULL;
 
-    (void) DBTreeSrTiles(&scx, &maskBits,
-	    ((DBWclientRec *) w->w_clientData)->dbw_bitmask,
-	    cmdCornerFunc, (ClientData) &hasErr);
+	(void) DBTreeSrTiles(&scx, &maskBits,
+		((DBWclientRec *) w->w_clientData)->dbw_bitmask,
+		cmdCornerFunc, (ClientData) &hasErr);
 
-    if (hasErr)
-	TxError("There's not enough room in the box for all the wires.\n");
+	if (hasErr)
+	    TxError("There's not enough room in the box for all the wires.\n");
 
-    /* Now that we've got all the material, scan over the list
-     * painting the material and freeing up the entries on the list.
-     */
-    while (cmdCornerList != NULL)
-    {
-	DBPaint(EditCellUse->cu_def, &cmdCornerList->cca_area,
-		cmdCornerList->cca_type);
-	freeMagic((char *) cmdCornerList);
-	cmdCornerList = cmdCornerList->cca_next;
+	/* Now that we've got all the material, scan over the list
+	 * painting the material and freeing up the entries on the list.
+	 */
+	while (cmdCornerList != NULL)
+	{
+	    DBPaint(EditCellUse->cu_def, &cmdCornerList->cca_area,
+			cmdCornerList->cca_type);
+	    freeMagic((char *) cmdCornerList);
+	    cmdCornerList = cmdCornerList->cca_next;
+	}
     }
 
-#ifdef NONMANHATTAN
-    }
-#endif
-
     SelectClear();
     DBAdjustLabels(EditCellUse->cu_def, &editBox);
     DRCCheckThis(EditCellUse->cu_def, TT_CHECKPAINT, &editBox);
@@ -2186,8 +2180,6 @@ cmdCornerFunc(tile, cxp)
     return 0;
 }
 
-#ifdef NONMANHATTAN
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -2716,7 +2708,6 @@ cmdBevelFunc(tile, cxp)
 
     return 0;	/* Keep the search going */
 }
-#endif  /* NONMANHATTAN */
 
 /*
  * ----------------------------------------------------------------------------
