@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdRS.c,v 1.10 2010/05/04 18:40:55 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdRS.c,v 1.13 2010/06/24 12:37:15 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -1378,11 +1378,14 @@ cmdLabelTextFunc(label, cellUse, transform, text)
     }
     else if (cellDef == EditRootDef)
     {
-	newlab = DBPutFontLabel(cellDef, &label->lab_rect, label->lab_font,
-		label->lab_size, label->lab_rotate, &label->lab_offset,
-		label->lab_just, text, label->lab_type, label->lab_flags);
-	DBEraseLabelsByContent(cellDef, &label->lab_rect, -1, label->lab_text);
-	DBWLabelChanged(cellDef, newlab, DBW_ALLWINDOWS);
+	if (strcmp(text, label->lab_text))
+	{
+	    newlab = DBPutFontLabel(cellDef, &label->lab_rect, label->lab_font,
+			label->lab_size, label->lab_rotate, &label->lab_offset,
+			label->lab_just, text, label->lab_type, label->lab_flags);
+	    DBEraseLabelsByContent(cellDef, &label->lab_rect, -1, label->lab_text);
+	    DBWLabelChanged(cellDef, newlab, DBW_ALLWINDOWS);
+	}
     }
     return 0;
 }
@@ -1667,7 +1670,7 @@ CmdSetLabel(w, cmd)
 	    {
 		SelEnumLabels(&DBAllTypeBits, FALSE, (bool *)NULL,
 			cmdLabelTextFunc, (cmd->tx_argc == 3) ?
-			(ClientData)cmd->tx_argv[2] : NULL);
+			(ClientData)cmd->tx_argv[2] : (ClientData)NULL);
 		SelectTransform(&GeoIdentityTransform);
 	    }
 	    break;
@@ -1711,7 +1714,7 @@ CmdSetLabel(w, cmd)
 		{
 		    SelEnumLabels(&DBAllTypeBits, FALSE, (bool *)NULL,
 				cmdLabelFontFunc, (cmd->tx_argc == 3) ?
-				(ClientData)&font : NULL);
+				(ClientData)&font : (ClientData)NULL);
 		    SelectTransform(&GeoIdentityTransform);
 		}
 	    }
@@ -1727,7 +1730,7 @@ CmdSetLabel(w, cmd)
 	    {
 		SelEnumLabels(&DBAllTypeBits, FALSE, (bool *)NULL,
 			cmdLabelJustFunc, (cmd->tx_argc == 3) ?
-			(ClientData)&pos : NULL);
+			(ClientData)&pos : (ClientData)NULL);
 		SelectTransform(&GeoIdentityTransform);
 	    }
 	    break;
@@ -1743,7 +1746,7 @@ CmdSetLabel(w, cmd)
 	    {
 		SelEnumLabels(&DBAllTypeBits, FALSE, (bool *)NULL,
 			cmdLabelSizeFunc, (cmd->tx_argc == 3) ?
-			(ClientData)&size : NULL);
+			(ClientData)&size : (ClientData)NULL);
 		SelectTransform(&GeoIdentityTransform);
 	    }
 	    break;
@@ -1751,8 +1754,17 @@ CmdSetLabel(w, cmd)
 	case SETLABEL_OFFSET:
 	    if (cmd->tx_argc == 3)
 	    {
-		TxError("Usage:  setlabel offset <x> <y>\n");
-		return;
+		char *yp;
+		if ((yp = strchr(cmd->tx_argv[2], ' ')) != NULL)
+		{
+		    offset.p_x = cmdScaleCoord(w, cmd->tx_argv[2], TRUE, TRUE, 8);
+		    offset.p_y = cmdScaleCoord(w, yp, TRUE, FALSE, 8);
+		}
+		else
+		{
+		    TxError("Usage:  setlabel offset <x> <y>\n");
+		    return;
+		}
 	    }
 	    else if (cmd->tx_argc == 4)
 	    {
@@ -1762,8 +1774,8 @@ CmdSetLabel(w, cmd)
 	    if (EditCellUse)
 	    {
 		SelEnumLabels(&DBAllTypeBits, FALSE, (bool *)NULL,
-			cmdLabelOffsetFunc, (cmd->tx_argc == 4) ?
-			(ClientData)&offset : NULL);
+			cmdLabelOffsetFunc, (cmd->tx_argc != 2) ?
+			(ClientData)&offset : (ClientData)NULL);
 		SelectTransform(&GeoIdentityTransform);
 	    }
 	    break;
@@ -1778,7 +1790,7 @@ CmdSetLabel(w, cmd)
 	    {
 		SelEnumLabels(&DBAllTypeBits, FALSE, (bool *)NULL,
 			cmdLabelRotateFunc, (cmd->tx_argc == 3) ?
-			(ClientData)&rotate : NULL);
+			(ClientData)&rotate : (ClientData)NULL);
 		SelectTransform(&GeoIdentityTransform);
 	    }
 	    break;
@@ -2126,7 +2138,6 @@ printit:
 }
 
 
-#ifdef NONMANHATTAN
 
 /*
  * ----------------------------------------------------------------------------
@@ -2210,7 +2221,7 @@ CmdSplit(w, cmd)
 				diag, &editRect, DBStdPaintTbl(t, pNum), &ui);
 			GEO_EXPAND(&editRect, 1, &expRect);
 			DBMergeNMTiles(EditCellUse->cu_def->cd_planes[pNum],
-				&expRect);
+				&expRect, &ui);
 		    }
 	    }
 	}
@@ -2299,7 +2310,7 @@ CmdSplitErase(w, cmd)
 				diag, &editRect, DBStdEraseTbl(t, pNum), &ui);
 		    GEO_EXPAND(&editRect, 1, &expRect);
 		    DBMergeNMTiles(EditCellUse->cu_def->cd_planes[pNum],
-				&expRect);
+				&expRect, &ui);
 		}
 	}
     }
@@ -2310,8 +2321,6 @@ CmdSplitErase(w, cmd)
     DRCCheckThis (EditCellUse->cu_def, TT_CHECKPAINT, &editRect);
 }
 
-#endif
-
 
 /*
  * ----------------------------------------------------------------------------
