@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdSubrs.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdSubrs.c,v 1.2 2010/06/24 12:37:15 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -107,9 +107,12 @@ cmdScaleCoord(w, arg, is_relative, is_x, scale)
 {
     char *endptr;
     double dval = 0;
-    int mscale;
+    int mscale = 1;
     DBWclientRec *crec;
 
+    if (*arg == '{') arg++;
+    while (isspace(*arg)) arg++;
+
     dval = strtod(arg, &endptr);
     dval *= (double)scale;
 
@@ -186,11 +189,11 @@ cmdScaleCoord(w, arg, is_relative, is_x, scale)
 		    return round(dval);
 	    }
 	}
-	else if (!strncmp(endptr, "micron", 5))
+	else if (!strncmp(endptr, "micron", 6))
 	    mscale = 1000;
 	else if (!strncmp(endptr, "centimicron", 11) || !strcmp(endptr, "cu"))
 	    mscale = 10;
-	else
+	else if (!isspace(*endptr))
 	{
 	    TxError("Unknown coordinate type \"%s\"; assuming internal units\n",
 			endptr);
