@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBcellsrch.c,v 1.4 2009/04/23 16:26:53 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBcellsrch.c,v 1.6 2010/08/15 14:35:47 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -121,16 +121,12 @@ DBTreeSrTiles(scx, mask, xMask, func, cdarg)
     filter.tf_arg = cdarg;
     filter.tf_mask = mask;
     filter.tf_xmask = xMask;
-#ifdef NONMANHATTAN
     filter.tf_dinfo = 0;
-#endif
     filter.tf_planes = DBTechTypesToPlanes(mask);
 
     return dbCellTileSrFunc(scx, &filter);
 }
 
-#ifdef NONMANHATTAN
-
 /*
  * DBTreeSrNMTiles --
  *	This is a variant of the above in which the search is over
@@ -173,8 +169,6 @@ DBTreeSrNMTiles(scx, dinfo, mask, xMask, func, cdarg)
     return dbCellTileSrFunc(scx, &filter);
 }
 
-#endif
-
 /*
  * dbCellTileSrFunc --
  *
@@ -208,7 +202,6 @@ dbCellTileSrFunc(scx, fp)
 	if (PlaneMaskHasPlane(fp->tf_planes, pNum))
 	{
 	    context.tc_plane = pNum;
-#ifdef NONMANHATTAN
 	    if (fp->tf_dinfo & TT_DIAGONAL)
 	    {
 		TileType dinfo = DBTransformDiagonal(fp->tf_dinfo, &scx->scx_trans);
@@ -217,9 +210,7 @@ dbCellTileSrFunc(scx, fp)
 			fp->tf_func, (ClientData) &context))
 		    return 1;
 	    }
-	    else
-#endif
-	    if (DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
+	    else if (DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
 		    &scx->scx_area, fp->tf_mask,
 		    fp->tf_func, (ClientData) &context))
 		return 1;
@@ -824,13 +815,11 @@ dbSeeTypesAllSrFunc(tile, cxp)
     TiToRect(tile, &tileRect);
     if (GEO_OVERLAP((&tileRect), area))
     {
-#ifdef NONMANHATTAN 
 	if (IsSplit(tile))
 	    TTMaskSetType(mask, SplitSide(tile) ?
 			SplitRightType(tile) : SplitLeftType(tile));
         else
-#endif
-	TTMaskSetType(mask, TiGetType(tile));
+	    TTMaskSetType(mask, TiGetType(tile));
     }
     return 0;
 }
@@ -1431,7 +1420,7 @@ DBScaleEverything(scalen, scaled)
     int dbCellDefEnumFunc();
     LinkedCellDef *lhead, *lcd;
 
-    DBUpdateStamps();
+    // DBUpdateStamps();
 
     SigDisableInterrupts();
 
@@ -1525,9 +1514,7 @@ dbTileScaleFunc(tile, scvals)
 {
     TileType type;
     Rect targetRect;
-#ifdef NONMANHATTAN
     TileType exact;
-#endif
 
     TiToRect(tile, &targetRect);
 
@@ -1546,7 +1533,6 @@ dbTileScaleFunc(tile, scvals)
     }
 
     type = TiGetTypeExact(tile);
-#ifdef NONMANHATTAN
     exact = type;
     if (IsSplit(tile))
 	type = (SplitSide(tile)) ? SplitRightType(tile) : SplitLeftType(tile);
@@ -1554,12 +1540,6 @@ dbTileScaleFunc(tile, scvals)
 		((scvals->doCIF) ? CIFPaintTable :
 		DBStdPaintTbl(type, scvals->pnum)),
 		(PaintUndoInfo *)NULL);
-#else
-    DBPaintPlane(scvals->ptarget, &targetRect,
-		((scvals->doCIF) ? CIFPaintTable :
-		DBStdPaintTbl(type, scvals->pnum)),
-		(PaintUndoInfo *)NULL);
-#endif
     return 0;
 }
 
