@@ -20,7 +20,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBconnect.c,v 1.4 2008/12/11 04:20:04 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBconnect.c,v 1.5 2010/06/24 12:37:15 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -71,9 +71,7 @@ typedef struct
 {
     Rect		area;		/* Area to process */
     TileTypeBitMask	*connectMask;	/* Connection mask for search */
-#ifdef NONMANHATTAN
     TileType		dinfo;		/* Info about triangular search areas */
-#endif
 } conSrArea;
 
 struct conSrArg2
@@ -93,8 +91,6 @@ struct conSrArg2
 
 #define CSA2_LIST_START_SIZE 256
 
-#ifdef NONMANHATTAN
-
 /*
  *-----------------------------------------------------------------
  * DBTransformDiagonal --
@@ -135,8 +131,6 @@ DBTransformDiagonal(oldtype, trans)
     return dinfo;
 }
 
-#endif
-
 
 /*
  * ----------------------------------------------------------------------------
@@ -337,7 +331,6 @@ dbSrConnectFunc(tile, csa)
      * recursively.
      */
     
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
 	if (SplitSide(tile))
@@ -346,26 +339,21 @@ dbSrConnectFunc(tile, csa)
 	    loctype = SplitLeftType(tile);
     }
     else
-#endif
-    loctype = TiGetTypeExact(tile);
+	loctype = TiGetTypeExact(tile);
     connectMask = &csa->csa_connect[loctype];
 
     /* Left side: */
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile) && SplitSide(tile)) goto bottomside;
-#endif
 
     for (t2 = BL(tile); BOTTOM(t2) < tileArea.r_ytop; t2 = RT(t2))
     {
-#ifdef NONMANHATTAN
 	if (IsSplit(t2))
 	{
 	    checktype = SplitRightType(t2);
 	}
 	else
-#endif
-	checktype = TiGetTypeExact(t2);
+	    checktype = TiGetTypeExact(t2);
 	if (TTMaskHasType(connectMask, checktype))
 	{
 	    if (csa->csa_clear)
@@ -380,21 +368,17 @@ dbSrConnectFunc(tile, csa)
     /* Bottom side: */
 
 bottomside:
-#ifdef NONMANHATTAN
     if (IsSplit(tile) && (!(SplitSide(tile) ^ SplitDirection(tile))))
 	goto rightside;
-#endif
 
     for (t2 = LB(tile); LEFT(t2) < tileArea.r_xtop; t2 = TR(t2))
     {
-#ifdef NONMANHATTAN
 	if (IsSplit(t2))
 	{
 	    checktype = SplitTopType(t2);
 	}
 	else
-#endif
-	checktype = TiGetTypeExact(t2);
+	    checktype = TiGetTypeExact(t2);
 	if (TTMaskHasType(connectMask, checktype))
 	{
 	    if (csa->csa_clear)
@@ -409,20 +393,16 @@ bottomside:
     /* Right side: */
 
 rightside:
-#ifdef NONMANHATTAN
     if (IsSplit(tile) && !SplitSide(tile)) goto topside;
-#endif
 
     for (t2 = TR(tile); ; t2 = LB(t2))
     {
-#ifdef NONMANHATTAN
 	if (IsSplit(t2))
 	{
 	    checktype = SplitLeftType(t2);
 	}
 	else
-#endif
-	checktype = TiGetTypeExact(t2);
+	    checktype = TiGetTypeExact(t2);
 	if (TTMaskHasType(connectMask, checktype))
 	{
 	    if (csa->csa_clear)
@@ -438,20 +418,16 @@ rightside:
     /* Top side: */
 topside:
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile) && (SplitSide(tile) ^ SplitDirection(tile))) goto donesides;
-#endif
 
     for (t2 = RT(tile); ; t2 = BL(t2))
     {
-#ifdef NONMANHATTAN
 	if (IsSplit(t2))
 	{
 	    checktype = SplitBottomType(t2);
 	}
 	else
-#endif
-	checktype = TiGetTypeExact(t2);
+	    checktype = TiGetTypeExact(t2);
 	if (TTMaskHasType(connectMask, checktype))
 	{
 	    if (csa->csa_clear)
@@ -483,7 +459,6 @@ donesides:
 	for (i = PL_TECHDEPBASE; i < DBNumPlanes; i++)
 	{
 	    newcsa.csa_plane = i;
-#ifdef NONMANHATTAN
 	    if (IsSplit(tile))
 	    {
 		if (DBSrPaintNMArea((Tile *) NULL, csa->csa_def->cd_planes[i],
@@ -491,9 +466,7 @@ donesides:
 			dbSrConnectFunc, (ClientData) &newcsa) != 0)
 		    return 1;
 	    }
-	    else
-#endif
-	    if (DBSrPaintArea((Tile *) NULL, csa->csa_def->cd_planes[i],
+	    else if (DBSrPaintArea((Tile *) NULL, csa->csa_def->cd_planes[i],
 			&newArea, connectMask, dbSrConnectFunc,
 			(ClientData) &newcsa) != 0) return 1;
 	}
@@ -640,9 +613,7 @@ dbcConnectFunc(tile, cx)
     SearchContext *scx = cx->tc_scx;
     SearchContext scx2;
     TileType loctype = TiGetTypeExact(tile);
-#ifdef NONMANHATTAN
     TileType dinfo = 0;
-#endif
     int pNum = cx->tc_plane;
     CellDef *def;
 
@@ -672,13 +643,11 @@ dbcConnectFunc(tile, cx)
     GeoClip(&newarea, csa2->csa2_bounds);
     if (GEO_RECTNULL(&newarea)) return 0;
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
 	dinfo = DBTransformDiagonal(loctype, &scx->scx_trans);
 	loctype = (SplitSide(tile)) ? SplitRightType(tile) : SplitLeftType(tile);
     }
-#endif
 
     /* See if the destination cell contains stuff over the whole
      * current area (on its home plane) that is connected to it.
@@ -730,31 +699,19 @@ dbcConnectFunc(tile, cx)
     /* which have not already been painted.			*/
 
     def = csa2->csa2_use->cu_def;
-#ifdef NONMANHATTAN
     if (DBSrPaintNMArea((Tile *) NULL, def->cd_planes[pNum],
 		dinfo, &newarea, &notConnectMask, dbcUnconnectFunc,
 		(ClientData) NULL) == 0)
 	return 0;
-#else
-    if (DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
-		&newarea, &notConnectMask, dbcUnconnectFunc,
-		(ClientData) NULL) == 0)
-	return 0;
-#endif
 
     /* Paint this tile into the destination cell.  This
      * marks its area has having been processed.  Then recycle
      * the storage for the current list element.
      */
 
-#ifdef NONMANHATTAN
     DBNMPaintPlane(def->cd_planes[pNum], dinfo,
 		&newarea, DBStdPaintTbl(loctype, pNum),
 		(PaintUndoInfo *) NULL);
-#else
-    DBPaintPlane(def->cd_planes[pNum], &newarea,
-	    DBStdPaintTbl(loctype, pNum), (PaintUndoInfo *) NULL);
-#endif
 
     /* Copy information from original context into new search context */
     scx2 = *csa2->csa2_topscx;
@@ -776,7 +733,6 @@ dbcConnectFunc(tile, cx)
      * even just touch.
      */
 
-#ifdef NONMANHATTAN
     /* Only extend those sides bordering the diagonal tile */
 	  
     if (dinfo & TT_DIAGONAL)
@@ -793,14 +749,11 @@ dbcConnectFunc(tile, cx)
     }
     else
     {
-#endif
-    newarea.r_ybot -= 1;
-    newarea.r_ytop += 1;
-    newarea.r_xbot -= 1;
-    newarea.r_xtop += 1;
-#ifdef NONMANHATTAN
+	newarea.r_ybot -= 1;
+	newarea.r_ytop += 1;
+	newarea.r_xbot -= 1;
+	newarea.r_xtop += 1;
     }
-#endif
 
     /* Register the area and connection mask as needing to be processed */
 
@@ -819,10 +772,7 @@ dbcConnectFunc(tile, cx)
 	{
 	    newlist[i].area = csa2->csa2_list[i].area;
 	    newlist[i].connectMask = csa2->csa2_list[i].connectMask;
-#ifdef NONMANHATTAN
 	    newlist[i].dinfo = csa2->csa2_list[i].dinfo;
-#endif
-	    
 	}
 	freeMagic((char *)csa2->csa2_list);
 	csa2->csa2_list = newlist;
@@ -830,9 +780,7 @@ dbcConnectFunc(tile, cx)
 
     csa2->csa2_list[csa2->csa2_top].area = newarea;
     csa2->csa2_list[csa2->csa2_top].connectMask = connectMask;
-#ifdef NONMANHATTAN
     csa2->csa2_list[csa2->csa2_top].dinfo = dinfo;
-#endif
 
     return 0;
 }
@@ -895,9 +843,7 @@ DBTreeCopyConnect(scx, mask, xMask, connect, area, destUse)
 {
     struct conSrArg2 csa2;
     TileTypeBitMask *newmask;
-#ifdef NONMANHATTAN
     TileType newtype;
-#endif
 
     csa2.csa2_use = destUse;
     csa2.csa2_xMask = xMask;
@@ -919,18 +865,14 @@ DBTreeCopyConnect(scx, mask, xMask, connect, area, destUse)
     {
 	newmask = csa2.csa2_list[csa2.csa2_top].connectMask;
 	scx->scx_area = csa2.csa2_list[csa2.csa2_top].area;
-#ifdef NONMANHATTAN
 	newtype = csa2.csa2_list[csa2.csa2_top].dinfo;
-#endif
 	csa2.csa2_top--;
 
-#ifdef NONMANHATTAN
 	if (newtype & TT_DIAGONAL)
 	    DBTreeSrNMTiles(scx, newtype, newmask, xMask, dbcConnectFunc,
 			(ClientData) &csa2);
 	else
-#endif
-	DBTreeSrTiles(scx, newmask, xMask, dbcConnectFunc, (ClientData) &csa2);
+	    DBTreeSrTiles(scx, newmask, xMask, dbcConnectFunc, (ClientData) &csa2);
     }
     freeMagic((char *)csa2.csa2_list);
 
