@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBtechtype.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBtechtype.c,v 1.2 2008/09/05 13:56:25 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -307,14 +307,16 @@ DBTechAddPlane(sectionName, argc, argv)
  */
 
 void
-DBTechAddNameToType(newname, ttype)
+DBTechAddNameToType(newname, ttype, canonical)
     char *newname;
     TileType ttype;
+    bool canonical;
 {
     char *cp;
 
     cp = dbTechNameAdd(newname, (ClientData) ttype, &dbTypeNameLists);
-    DBTypeLongNameTbl[ttype] = cp;
+    if (canonical)
+	DBTypeLongNameTbl[ttype] = cp;
 }
 
 /*
@@ -369,7 +371,7 @@ DBTechAddAlias(sectionName, argc, argv)
     if ((atype = DBTechNameType(argv[1])) >= 0)
 	if (TTMaskEqual(&DBLayerTypeMaskTbl[atype], &tmask))
 	{
-	    DBTechAddNameToType(argv[0], atype);
+	    DBTechAddNameToType(argv[0], atype, FALSE);
 	    return TRUE;
         }
 
