@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBundo.c,v 1.2 2009/05/02 01:18:36 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBundo.c,v 1.4 2010/06/24 12:37:15 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -41,7 +41,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 /***
  *** Identifiers for each of the clients defined here
  ***/
-UndoType dbUndoIDPaint;
+UndoType dbUndoIDPaint, dbUndoIDSplit, dbUndoIDJoin;
 UndoType dbUndoIDPutLabel, dbUndoIDEraseLabel;
 UndoType dbUndoIDOpenCell, dbUndoIDCloseCell;
 UndoType dbUndoIDCellUse;
@@ -52,6 +52,9 @@ UndoType dbUndoIDCellUse;
     /* Paint */
 void dbUndoPaintForw(), dbUndoPaintBack();
 
+    /* Split */
+void dbUndoSplitForw(), dbUndoSplitBack();
+
     /* Labels */
 void dbUndoLabelForw(), dbUndoLabelBack();
 
@@ -133,6 +136,13 @@ DBUndoInit()
 			(UndoEvent *(*)()) NULL, (int (*)()) NULL,
 			dbUndoPaintForw, dbUndoPaintBack, "paint");
 
+    /* Tile Splits */
+    dbUndoIDSplit = UndoAddClient(dbUndoInit, dbUndoCloseCell,
+			(UndoEvent *(*)()) NULL, (int (*)()) NULL,
+			dbUndoSplitForw, dbUndoSplitBack, "split");
+    dbUndoIDJoin = UndoAddClient(dbUndoInit, dbUndoCloseCell,
+			(UndoEvent *(*)()) NULL, (int (*)()) NULL,
+			dbUndoSplitBack, dbUndoSplitForw, "join");
 
     /* Labels */
     dbUndoIDPutLabel = UndoAddClient(nullProc, nullProc,
@@ -228,6 +238,46 @@ dbUndoInit()
  * ============================================================================
  */
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * dbUndoSplitForw --
+ * dbUndoSplitBack --
+ *
+ * Play forward/backward a tile split event.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Modifies the database.
+ *
+ * ----------------------------------------------------------------------------
+ */
+void
+dbUndoSplitForw(us)
+    splitUE *us;
+{
+    /* Create internal fracture */
+    DBSplitTile(dbUndoLastCell->cd_planes[us->sue_plane], &us->sue_point,
+		us->sue_splitx);
+}
+
+void
+dbUndoSplitBack(us)
+    splitUE *us;
+{
+    Rect srect;
+
+    srect.r_ll = us->sue_point;
+    srect.r_ur.p_x = us->sue_point.p_x + 1;
+    srect.r_ur.p_y = us->sue_point.p_y + 1;
+
+    /* Remove internal fracture and restore original split tile */
+    DBMergeNMTiles0(dbUndoLastCell->cd_planes[us->sue_plane], &srect,
+		(PaintUndoInfo *)NULL, TRUE);
+}
+
 /***
  *** The procedures to record paint undo events have been expanded
  *** in-line in DBPaintPlane() for speed.
@@ -254,12 +304,8 @@ void
 dbUndoPaintForw(up)
     paintUE *up;
 {
-#ifdef NONMANHATTAN 
     TileType loctype, dinfo;
 
-    if ((up->pue_newtype == up->pue_oldtype) && (up->pue_newtype & TT_DIAGONAL))
-	return;		/* ignore 4-way splits on undo forward */
-
     if (up->pue_oldtype & TT_DIAGONAL)
     {
 	loctype = (up->pue_oldtype & TT_LEFTMASK);
@@ -277,11 +323,10 @@ dbUndoPaintForw(up)
 		(PaintUndoInfo *) NULL);
     }
     else
-#endif
-    DBPaintPlane(dbUndoLastCell->cd_planes[up->pue_plane], &up->pue_rect,
+	DBPaintPlane(dbUndoLastCell->cd_planes[up->pue_plane], &up->pue_rect,
 			DBStdEraseTbl(up->pue_oldtype, up->pue_plane),
 			(PaintUndoInfo *) NULL);
-#ifdef NONMANHATTAN
+
     if (up->pue_newtype & TT_DIAGONAL)
     {
 	loctype = (up->pue_newtype & TT_LEFTMASK);
@@ -299,8 +344,7 @@ dbUndoPaintForw(up)
 		(PaintUndoInfo *) NULL);
     }
     else
-#endif
-    DBPaintPlane(dbUndoLastCell->cd_planes[up->pue_plane], &up->pue_rect,
+	DBPaintPlane(dbUndoLastCell->cd_planes[up->pue_plane], &up->pue_rect,
 			DBStdPaintTbl(up->pue_newtype, up->pue_plane),
 			(PaintUndoInfo *) NULL);
 endPaintFor:
@@ -313,17 +357,8 @@ void
 dbUndoPaintBack(up)
     paintUE *up;
 {
-#ifdef NONMANHATTAN
     TileType loctype, dinfo;
 
-    if ((up->pue_newtype == up->pue_oldtype) && (up->pue_newtype & TT_DIAGONAL))
-    {
-	/* Paint TT_SPACE into area to remove any internal fractures */
-	DBPaintPlane(dbUndoLastCell->cd_planes[up->pue_plane], &up->pue_rect,
-			DBStdPaintTbl(TT_SPACE, up->pue_plane),
-			(PaintUndoInfo *) NULL);
-    }
-
     if (up->pue_newtype & TT_DIAGONAL)
     {
 	loctype = (up->pue_newtype & TT_LEFTMASK);
@@ -341,11 +376,10 @@ dbUndoPaintBack(up)
 		(PaintUndoInfo *) NULL);
     }
     else
-#endif
-    DBPaintPlane(dbUndoLastCell->cd_planes[up->pue_plane], &up->pue_rect,
+	DBPaintPlane(dbUndoLastCell->cd_planes[up->pue_plane], &up->pue_rect,
 			DBStdEraseTbl(up->pue_newtype, up->pue_plane),
 			(PaintUndoInfo *) NULL);
-#ifdef NONMANHATTAN
+
     if (up->pue_oldtype & TT_DIAGONAL)
     {
 	loctype = (up->pue_oldtype & TT_LEFTMASK);
@@ -361,10 +395,12 @@ dbUndoPaintBack(up)
 	DBNMPaintPlane(dbUndoLastCell->cd_planes[up->pue_plane], dinfo,
 		&up->pue_rect, DBStdPaintTbl(loctype, up->pue_plane),
 		(PaintUndoInfo *) NULL);
+
+	DBMergeNMTiles0(dbUndoLastCell->cd_planes[up->pue_plane],
+		&up->pue_rect, (PaintUndoInfo *)NULL, TRUE);
     }
     else
-#endif
-    DBPaintPlane(dbUndoLastCell->cd_planes[up->pue_plane], &up->pue_rect,
+	DBPaintPlane(dbUndoLastCell->cd_planes[up->pue_plane], &up->pue_rect,
 			DBStdPaintTbl(up->pue_oldtype, up->pue_plane),
 			(PaintUndoInfo *) NULL);
 
