@@ -20,7 +20,7 @@
  */
 
 #ifndef	lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCbasic.c,v 1.4 2010/05/14 18:58:00 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCbasic.c,v 1.5 2010/06/24 12:37:16 tim Exp $";
 #endif	/* not lint */
 
 #include <sys/types.h>
@@ -55,8 +55,6 @@ extern int areaCheck();
 extern int drcTile();
 extern MaxRectsData *drcCanonicalMaxwidth();
 
-#ifdef NONMANHATTAN
-
 /*
  *-----------------------------------------------------------------------
  *
@@ -107,8 +105,6 @@ point_to_segment(px, py, s1x, s1y, s2x, s2y)
     }
 }
 
-#endif	/* NONMANHATTAN */
-
 /* Define Euclidean distance checks */
 
 #define RADIAL_NW	0x1000
@@ -185,7 +181,6 @@ areaCheck(tile, arg)
 			- arg->dCD_constraint->r_ytop + sdist) >= 0)
 			&& ((sqx * sqx + sqy * sqy) >= ssdist))
 		return 0;
-#ifdef NONMANHATTAN
 	    else if (IsSplit(tile) && !SplitDirection(tile) && !SplitSide(tile))
 	    {
 		sstest = point_to_segment(arg->dCD_constraint->r_xbot + sdist,
@@ -193,7 +188,6 @@ areaCheck(tile, arg)
 			LEFT(tile), BOTTOM(tile), RIGHT(tile), TOP(tile));
 		if (sstest > ssdist) return 0;
 	    }
-#endif
 	}
 	if ((arg->dCD_radial & RADIAL_NE) != 0)
 	{
@@ -202,7 +196,6 @@ areaCheck(tile, arg)
 			- arg->dCD_constraint->r_ytop + sdist) >= 0)
 			&& ((sqx * sqx + sqy * sqy) >= ssdist))
 		return 0;
-#ifdef NONMANHATTAN
 	    else if (IsSplit(tile) && SplitDirection(tile) && SplitSide(tile))
 	    {
 		sstest = point_to_segment(arg->dCD_constraint->r_xtop - sdist,
@@ -210,7 +203,6 @@ areaCheck(tile, arg)
 			LEFT(tile), TOP(tile), RIGHT(tile), BOTTOM(tile));
 		if (sstest > ssdist) return 0;
 	    }
-#endif
 	}
 	if ((arg->dCD_radial & RADIAL_SW) != 0)
 	{
@@ -220,7 +212,6 @@ areaCheck(tile, arg)
 			+ sdist - rect.r_ytop) >= 0)
 			&& ((sqx * sqx + sqy * sqy) >= ssdist))
 		return 0;
-#ifdef NONMANHATTAN
 	    else if (IsSplit(tile) && SplitDirection(tile) && !SplitSide(tile))
 	    {
 		sstest = point_to_segment(arg->dCD_constraint->r_xbot + sdist,
@@ -228,7 +219,6 @@ areaCheck(tile, arg)
 			LEFT(tile), TOP(tile), RIGHT(tile), BOTTOM(tile));
 		if (sstest > ssdist) return 0;
 	    }
-#endif
 	}
 	if ((arg->dCD_radial & RADIAL_SE) != 0)
 	{
@@ -238,7 +228,6 @@ areaCheck(tile, arg)
 			+ sdist - rect.r_ytop) >= 0)
 			&& ((sqx * sqx + sqy * sqy) >= ssdist))
 		return 0;
-#ifdef NONMANHATTAN
 	    else if (IsSplit(tile) && !SplitDirection(tile) && SplitSide(tile))
 	    {
 		sstest = point_to_segment(arg->dCD_constraint->r_xtop - sdist,
@@ -246,7 +235,6 @@ areaCheck(tile, arg)
 			LEFT(tile), BOTTOM(tile), RIGHT(tile), TOP(tile));
 		if (sstest > ssdist) return 0;
 	    }
-#endif
 	}
     }
 
@@ -397,7 +385,6 @@ drcTile (tile, arg)
         (*(arg->dCD_errors))++;
     }
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
 	/* Check rules for DRC_ANGLES rule and process */
@@ -427,7 +414,6 @@ drcTile (tile, arg)
         /* This drc is only for the left edge of the tile */
 	if (SplitSide(tile)) goto checkbottom;
     }
-#endif  
 
     /*
      * Check design rules along a vertical boundary between two tiles.
@@ -774,14 +760,11 @@ drcTile (tile, arg)
         }
     }
 
-#ifdef NONMANHATTAN
-
     /* This drc is only for the bottom edge of the tile */
 
 checkbottom:
     if (IsSplit(tile))
 	if (SplitSide(tile) == SplitDirection(tile)) return 0;
-#endif          
 
     /*
      * Check design rules along a horizontal boundary between two tiles.
