@@ -20,7 +20,7 @@
  */
 
 #ifndef	lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCcontin.c,v 1.6 2009/09/11 18:03:47 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCcontin.c,v 1.7 2010/03/12 17:19:45 tim Exp $";
 #endif	/* not lint */
 
 #include <stdio.h>
@@ -479,7 +479,8 @@ DRCContinuous()
 				 *  returns 1, meaning that a CHECK tile
 				 *  was found and processed.
 				 */
-	while (DBSrPaintArea ((Tile *) NULL,
+	while ((DRCPendingRoot != (DRCPendingCookie *)NULL) &&
+	    DBSrPaintArea ((Tile *) NULL,
 	    DRCPendingRoot->dpc_def->cd_planes [PL_DRC_CHECK],
 	    &TiPlaneRect, &DBAllButSpaceBits, drcCheckTile, (ClientData) NULL))
 	{
@@ -512,9 +513,11 @@ DRCContinuous()
 
 	/* No check tiles were found, so knock this cell off the list. */
 
-	DBReComputeBbox(DRCPendingRoot->dpc_def);
-	freeMagic((char *) DRCPendingRoot);
-	DRCPendingRoot = DRCPendingRoot->dpc_next;
+	if (DRCPendingRoot != (DRCPendingCookie *)NULL) {
+	    DBReComputeBbox(DRCPendingRoot->dpc_def);
+	    freeMagic((char *) DRCPendingRoot);
+	    DRCPendingRoot = DRCPendingRoot->dpc_next;
+	}
 
 	/* Give the timestamp manager a chance to update any mismatches. */
 
