@@ -1,6 +1,6 @@
 
 #ifndef	lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCextend.c,v 1.4 2009/01/19 15:43:03 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCextend.c,v 1.5 2010/06/24 12:37:16 tim Exp $";
 #endif	
 
 #include <sys/types.h>
@@ -29,8 +29,6 @@ Stack *DRCstack = (Stack *)NULL;
         STACKPUSH((ClientData) (tp), DRCstack); \
     }
 
-#ifdef NONMANHATTAN
-
 /*
  *-------------------------------------------------------------------------
  *
@@ -72,22 +70,6 @@ drcCheckAngles(tile, arg, cptr)
     }
 }
 
-#else
-
-/* When non-Manhattan geometry is not compiled in, this routine	*/
-/* is merely a placeholder.					*/
-
-void
-drcCheckAngles(tile, arg, cptr)
-    Tile	*starttile;
-    struct drcClientData *arg;
-    DRCCookie	*cptr;
-{
-    /* Do nothing */
-}
-
-#endif	/* NONMANHATTAN */
-
 /*
  *-------------------------------------------------------------------------
  *
