@@ -19,7 +19,7 @@
  */
 
 #ifndef	lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCmain.c,v 1.3 2010/03/08 13:33:33 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCmain.c,v 1.4 2010/06/24 12:37:16 tim Exp $";
 #endif	/* not lint */
 
 #include <sys/types.h>
@@ -550,7 +550,7 @@ drcCountFunc(scx, dupTable)
      */
 
     def = scx->scx_use->cu_def;
-    h = HashFind(dupTable, def);
+    h = HashFind(dupTable, (char *)def);
     if (HashGetValue(h) != 0) goto done;
     HashSetValue(h, 1);
 
@@ -703,7 +703,7 @@ drcFindFunc(scx, finddata)
     int drcFindFunc2();
 
     def = scx->scx_use->cu_def;
-    h = HashFind(finddata->deft, def);
+    h = HashFind(finddata->deft, (char *)def);
     if (HashGetValue(h) != 0) return 0;
     HashSetValue(h, 1);
 
