@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCtech.c,v 1.7 2010/05/13 21:28:52 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCtech.c,v 1.8 2010/06/24 12:37:16 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -1445,8 +1445,6 @@ drcMaxwidth(argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-#ifdef NONMANHATTAN
-
 int
 drcAngles(argc, argv)
     int argc;
@@ -1492,19 +1490,6 @@ drcAngles(argc, argv)
     return 1;
 }
 
-#else
-
-int
-drcAngles(argc, argv)
-    int argc;
-    char *argv[];
-{
-    TechError("Angle limits ignored (no non-Manhattan geometry allowed).\n");
-    return 0;
-}
-
-#endif	/* NONMANHATTAN */
-
 /*
  * ----------------------------------------------------------------------------
  *
