@@ -17,7 +17,7 @@
  *
  * Needs to include: magic.h database.h
  *
- * rcsid $Header: /usr/cvsroot/magic-8.0/drc/drc.h,v 1.3 2008/12/04 16:21:44 tim Exp $
+ * rcsid $Header: /usr/cvsroot/magic-8.0/drc/drc.h,v 1.4 2009/09/11 15:47:09 tim Exp $
  */
 
 #ifndef _DRC_H
@@ -75,6 +75,13 @@ enum { DRC_NOT_RUNNING, DRC_IN_PROGRESS, DRC_BREAK_PENDING };
 extern unsigned char DRCStatus;
 #endif
 
+/*
+ * States of the background checker.  This allows us to force an off state
+ * during initialization while allowing the startup scripts to set the
+ * state on or off.
+ */
+enum { DRC_SET_OFF, DRC_SET_ON, DRC_NOT_SET };
+
 /* This is client data passed down through the various DRC checking
  * routines, and contains information about the area and rule being
  * checked.
@@ -185,7 +192,7 @@ extern int DRCTechHalo;		/* Current halo being used */
 extern int DRCStepSize;		/* Current step size being used */
 extern DRCPendingCookie * DRCPendingRoot;
 
-extern bool DRCBackGround;	/* global flag to enable/disable
+extern u_char DRCBackGround;	/* global flag to enable/disable
 				 * continuous DRC
 			     	 */
 extern bool DRCEuclidean;	/* global flag to enable/disable
@@ -249,6 +256,10 @@ extern void DRCLoadStyle();
  * the background checker needs to be called.
  */
 
-#define DRCHasWork ((DRCPendingRoot != NULL) && (DRCBackGround))
+#ifdef MAGIC_WRAPPER
+#define DRCHasWork ((DRCPendingRoot != NULL) && (DRCBackGround == DRC_SET_ON))
+#else
+#define DRCHasWork ((DRCPendingRoot != NULL) && (DRCBackGround != DRC_SET_OFF))
+#endif
 
 #endif /* _DRC_H */
