@@ -2,7 +2,7 @@
  * ext2spice.c --
  *
  * Program to flatten hierarchical .ext files and produce
- * a .spice file, suitable for use as input to spiceulators
+ * a .spice file, suitable for use as input to simulators
  * such as spice and hspice.
  *
  * Flattens the tree rooted at file.ext, reading in additional .ext
@@ -13,7 +13,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/ext2spice/ext2spice.c,v 1.5 2009/09/10 20:32:52 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/ext2spice/ext2spice.c,v 1.8 2010/08/25 17:33:56 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -42,22 +42,12 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #include "extract/extract.h"	/* for extDevTable */
 #include "utils/runstats.h"
 
-/* Forward declarations */
-#ifdef MAGIC_WRAPPER
-void CmdExtToSpice();
-#endif
-int spcmainArgs();
-int spccapVisit(), spcdevVisit(), spcnodeVisit(), subcktVisit(), spcresistVisit(), 
-    devMergeVisit(), devDistJunctVisit();
-int subcktUndef();
-EFNode *spcdevSubstrate();
-char *nodeSpiceName();
-
-#define AUTO	2	/* TRUE | FALSE | AUTO for esDoSubckt */
+#include "ext2spice/ext2spice.h"
 
 /* Options specific to ext2spice */
 bool esDoExtResis = FALSE;
 bool esDoPorts = TRUE;
+bool esDoHierarchy = FALSE;
 bool esDoResistorTee = FALSE;
 int  esDoSubckt = AUTO;
 bool esDevNodesOnly = FALSE;
@@ -70,11 +60,7 @@ char *spcesOutName = spcesDefaultOut;
 FILE *esSpiceF = NULL;
 float esScale = -1.0 ; /* negative if hspice the EFScale/100 otherwise */
 
-#define	SPICE2	0
-#define	SPICE3	1
-#define	HSPICE	2
-
-static unsigned short esFormat = SPICE3 ;
+unsigned short esFormat = SPICE3 ;
 
 int esCapNum, esDevNum, esResNum, esDiodeNum;
 int esNodeNum;  /* just in case we're extracting spice2 */
@@ -90,77 +76,11 @@ int esNoModelType;  /* index for device type "None" (model-less device) */
 HashTable subcktNameTable ; /* the hash table itself */
 DQueue    subcktNameQueue ; /* q used to print it sorted at the end*/
 
-
-#define MAX_STR_SIZE (1<<11) /* 2K should be enough for keeping temp
-                                names even of the most complicated design */
-
-struct {
-   short resClassSD ;  /* the resistance class of the src/drn of the dev */
-   short resClassSub ; /* the resistance class of the substrate of the dev */
-   char  *defSubs ;    /* the default substrate node */
-} fetInfo[MAXDEVTYPES];
+fetInfoList fetInfo[MAXDEVTYPES];
 
 
-/* Node clients for figuring out areas and perimeters of sources and drains */
-typedef struct { 
-	long	_duml:MAXDEVTYPES; 
-} _dum; /* if you get an error here you should change 
-           the data structures and visitMask */
-
-typedef union {
-	long	visitMask; /* mask for normal visits */
-	float	*widths; /* width used for distributing area perim */
-} maskOrWidth ;
-
-typedef struct {
-	char		*spiceNodeName;
-	maskOrWidth	m_w;
-} nodeClient;
-
-typedef struct {
-	HierName 	*lastPrefix;
-	maskOrWidth	m_w;
-} nodeClientHier;
-
-#define	NO_RESCLASS	-1
-
-#define markVisited(client, rclass) \
-  { (client)->m_w.visitMask |= (1<<rclass); }
-
-#define clearVisited(client) \
-   { (client)->m_w.visitMask = (long)0; }
-
-#define beenVisited(client, rclass)  \
-   ( (client)->m_w.visitMask & (1<<rclass))
-
-/*
- * Used to mark the nodes which are connected to devs. initMask  is set to
- * DEV_CONNECT_MASK only when we are in visitDevs 
- */
-#define	DEV_CONNECT_MASK	((unsigned long)1<<(sizeof(long)*BITSPERCHAR-1))
 unsigned long	initMask = 0;
 
-#define initNodeClient(node) \
-{ \
-	(node)->efnode_client = (ClientData) mallocMagic((unsigned) (sizeof(nodeClient))); \
-	 (( nodeClient *)(node)->efnode_client)->spiceNodeName = NULL; \
-	(( nodeClient *)(node)->efnode_client)->m_w.visitMask = (unsigned long)initMask; \
-}
-
-
-#define initNodeClientHier(node) \
-{ \
-	(node)->efnode_client = (ClientData) mallocMagic((unsigned)(sizeof(nodeClientHier))); \
-	((nodeClientHier *) (node)->efnode_client)->m_w.visitMask = (unsigned long) 0; \
-}
-
-
-
-/* attributes controlling the Area/Perimeter extraction of dev terminals */
-#define ATTR_FLATAP	"*[Ee][Xx][Tt]:[Aa][Pp][Ff]*"
-#define ATTR_HIERAP	"*[Ee][Xx][Tt]:[Aa][Pp][Hh]*"
-#define ATTR_SUBSAP	"*[Ee][Xx][Tt]:[Aa][Pp][Ss]*"
-
 bool esMergeDevsA = FALSE; /* aggresive merging of devs L1=L2 merge them */
 bool esMergeDevsC = FALSE; /* conservative merging of devs L1=L2 and W1=W2 */
 			   /* used with the hspice multiplier */
@@ -174,20 +94,11 @@ bool esDistrJunct = FALSE;
  * value of esFMult[i] keeps the multiplier for the ith dev
  *---------------------------------------------------------
  */
-#define	DEV_KILLED	((float) -1.0)
-#define	FMULT_SIZE	(1<<10)
 
-static float	*esFMult = NULL;         /* the array itself */
-static int	 esFMIndex = 0;          /* current index to it */
-static int	 esFMSize = FMULT_SIZE ; /* its current size (growable) */
-
-static int	 esDevsMerged;
-
-#define	devIsKilled(n) ( esFMult[(n)] <=(float)0.0 )
-
-#define	DEV_KILLED	((float) -1.0)
-
-int nodeVisitDebug();
+float	*esFMult = NULL;         /* the array itself */
+int	 esFMIndex = 0;          /* current index to it */
+int	 esFMSize = FMULT_SIZE ; /* its current size (growable) */
+int	 esDevsMerged;
 
 /* macro to add a dev's multiplier to the table and grow it if necessary */
 #define addDevMult(f) \
@@ -204,33 +115,10 @@ int nodeVisitDebug();
 	esFMult[esFMIndex++] = (float)(f); \
 }
 
-#define	setDevMult(i,f) { esFMult[(i)] = (float)(f); }
-
-#define	getCurDevMult() ((esFMult) ? esFMult[esFMIndex-1] : (float)1.0)
-
-/* cache list used to find parallel devs */
-typedef struct _devMerge {
-	int     l, w;
-	EFNode *g, *s, *d, *b;
-	Dev * dev;
-	int	  esFMIndex;
-	HierName *hierName;
-	struct _devMerge *next;
-} devMerge;
-
 devMerge *devMergeList = NULL ;
 
-
-
-void topVisit();
-
 #ifdef MAGIC_WRAPPER
 
-#define 	atoCap(s)	((EFCapValue)atof(s))
-
-/* Forward declaration */
-int _ext2spice_start();
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -284,7 +172,8 @@ Exttospice_Init(interp)
 #define EXTTOSPC_RESISTORTEE	7
 #define EXTTOSPC_SCALE		8
 #define EXTTOSPC_SUBCIRCUITS	9
-#define EXTTOSPC_HELP		10
+#define EXTTOSPC_HIERARCHY	10
+#define EXTTOSPC_HELP		11
 
 void
 CmdExtToSpice(w, cmd)
@@ -313,7 +202,7 @@ CmdExtToSpice(w, cmd)
     static int LocResistThreshold = INFINITE_THRESHOLD; 
 
     static char *cmdExtToSpcOption[] = {
-	"[run] [options]	run exttosim on current cell\n"
+	"[run] [options]	run exttospice on current cell\n"
 	"			use \"run -help\" to get standard options",
 	"default		reset to default values",
 	"format [<type>]	set output format",
@@ -324,6 +213,7 @@ CmdExtToSpice(w, cmd)
 	"resistor tee [on|off]	model resistor capacitance as a T-network",
 	"scale [on|off]		use .option card for scaling",
 	"subcircuits [on|off]	standard cells become subcircuit calls",
+	"hierarchy [on|off]	output hierarchical spice for LVS",
 	"help			print help information",
 	NULL
     };
@@ -349,7 +239,17 @@ CmdExtToSpice(w, cmd)
 	"no",
 	"false",
 	"off",
-	"automatic", 
+	NULL
+    };
+
+    static char *subcktopts[] = {
+	"yes",
+	"true",
+	"on",
+	"no",
+	"false",
+	"off",
+	"automatic",
 	"top",
 	"descend",
 	NULL
@@ -413,13 +313,27 @@ CmdExtToSpice(w, cmd)
 	    else esScale = 0.0;
 	    break;
 
+	case EXTTOSPC_HIERARCHY:
+	    if (cmd->tx_argc == 2)
+	    {
+		Tcl_SetResult(magicinterp, (esDoHierarchy) ? "on" : "off", NULL);
+		return;
+	    }
+	    idx = Lookup(cmd->tx_argv[2], yesno);
+	    if (idx < 0) goto usage;
+	    else if (idx < 3)	/* yes */
+		esDoHierarchy = TRUE;
+	    else	 /* no */
+		esDoHierarchy = FALSE;
+	    break;
+
 	case EXTTOSPC_SUBCIRCUITS:
 	    if (cmd->tx_argc == 2)
 	    {
 		Tcl_SetResult(magicinterp, (esDoPorts) ? "on" : "off", NULL);
 		return;
 	    }
-	    idx = Lookup(cmd->tx_argv[2], yesno);
+	    idx = Lookup(cmd->tx_argv[2], subcktopts);
 	    switch (idx) {
 		case IDX_YES: case IDX_TRUE: case IDX_ON:
 		    esDoPorts = TRUE;
@@ -443,14 +357,13 @@ CmdExtToSpice(w, cmd)
 			return;
 		    }
 		    break;
-		case IDX_AUTO:
 		default:
 		    goto usage;
 		    break;
 	    }
 
 	    if (cmd->tx_argc != 4) goto usage;
-	    idx2 = Lookup(cmd->tx_argv[3], yesno);
+	    idx2 = Lookup(cmd->tx_argv[3], subcktopts);
 	    switch (idx2) {
 		case IDX_YES: case IDX_TRUE: case IDX_ON:
 		    if (idx == IDX_DESCEND)
@@ -467,8 +380,6 @@ CmdExtToSpice(w, cmd)
 		case IDX_AUTO:
 		    esDoSubckt = AUTO;
 		    break;
-		case IDX_DESCEND:
-		case IDX_TOP:
 		default:
 		    goto usage;
 	    }
@@ -752,59 +663,66 @@ runexttospice:
 	DQInit(&subcktNameQueue, 64);
 #endif
     }
-    EFFlatBuild(inName, flatFlags);
-
-    /* Determine if this is a subcircuit */
     locDoSubckt = FALSE;
-    if (esDoSubckt == AUTO) {
-	if (efFlatRootDef->def_flags & DEF_SUBCIRCUIT)
-	    locDoSubckt = TRUE;
-    }
-    if ((esDoSubckt == TRUE) || (locDoSubckt == TRUE))
-	topVisit(efFlatRootDef);
-
-    /* If we don't want to write subcircuit calls, remove the	*/
-    /* subcircuit flag from all cells at this time.		*/
-
-    if (!esDoPorts)
-	EFVisitSubcircuits(subcktUndef, (ClientData) NULL);
-
-    initMask = ( esDistrJunct  ) ? (unsigned long)0 : DEV_CONNECT_MASK;
-
-    if (esMergeDevsA || esMergeDevsC)
+    if (esDoHierarchy)
     {
-	EFVisitDevs(devMergeVisit, (ClientData) NULL);
-	TxPrintf("Devs merged: %d\n", esDevsMerged);
-	esFMIndex = 0;
-	{
-	    devMerge *p;
+	ESGenerateHierarchy(inName);
+    }
+    else
+    {
+	EFFlatBuild(inName, flatFlags);
 
-	    for (p = devMergeList; p != NULL; p = p->next)
-		freeMagic(p);
-	    devMergeList = NULL;
+	/* Determine if this is a subcircuit */
+	if (esDoSubckt == AUTO) {
+	    if (efFlatRootDef->def_flags & DEF_SUBCIRCUIT)
+		locDoSubckt = TRUE;
 	}
+	if ((esDoSubckt == TRUE) || (locDoSubckt == TRUE))
+	    topVisit(efFlatRootDef);
+
+	/* If we don't want to write subcircuit calls, remove	*/
+	/* the subcircuit flag from all cells at this time.	*/
+
+	if (!esDoPorts)
+	    EFVisitSubcircuits(subcktUndef, (ClientData) NULL);
+
+	initMask = ( esDistrJunct  ) ? (unsigned long)0 : DEV_CONNECT_MASK;
+
+	if (esMergeDevsA || esMergeDevsC)
+	{
+	    EFVisitDevs(devMergeVisit, (ClientData) NULL);
+	    TxPrintf("Devs merged: %d\n", esDevsMerged);
+	    esFMIndex = 0;
+	    {
+		devMerge *p;
+
+		for (p = devMergeList; p != NULL; p = p->next)
+		    freeMagic(p);
+		devMergeList = NULL;
+	    }
+	}
+	else if (esDistrJunct)
+     	    EFVisitDevs(devDistJunctVisit, (ClientData) NULL);
+	EFVisitDevs(spcdevVisit, (ClientData) NULL);
+	initMask = (unsigned long) 0;
+	if (flatFlags & EF_FLATCAPS)
+	{
+	    (void) sprintf( esCapFormat,  "C%%d %%s %%s %%.%dlffF\n", esCapAccuracy);
+	    EFVisitCaps(spccapVisit, (ClientData) NULL);
+	}
+	EFVisitResists(spcresistVisit, (ClientData) NULL);
+	EFVisitSubcircuits(subcktVisit, (ClientData) NULL);
+	(void) sprintf( esCapFormat, "C%%d %%s %s %%.%dlffF%%s", resstr, esCapAccuracy);
+	EFVisitNodes(spcnodeVisit, (ClientData) NULL);
+
+	if ((esDoSubckt == TRUE) || (locDoSubckt == TRUE))
+	    fprintf(esSpiceF, ".ends\n");
+
+	if (esFormat == HSPICE) 
+	    printSubcktDict();
+
+	EFFlatDone(); 
     }
-    else if (esDistrJunct)
-     	EFVisitDevs(devDistJunctVisit, (ClientData) NULL);
-    EFVisitDevs(spcdevVisit, (ClientData) NULL);
-    initMask = (unsigned long) 0;
-    if (flatFlags & EF_FLATCAPS)
-    {
-	(void) sprintf( esCapFormat,  "C%%d %%s %%s %%.%dlffF\n", esCapAccuracy);
-	EFVisitCaps(spccapVisit, (ClientData) NULL);
-    }
-    EFVisitResists(spcresistVisit, (ClientData) NULL);
-    EFVisitSubcircuits(subcktVisit, (ClientData) NULL);
-    (void) sprintf( esCapFormat, "C%%d %%s %s %%.%dlffF%%s", resstr, esCapAccuracy);
-    EFVisitNodes(spcnodeVisit, (ClientData) NULL);
-
-    if ((esDoSubckt == TRUE) || (locDoSubckt == TRUE))
-	fprintf(esSpiceF, ".ends\n");
-
-    if (esFormat == HSPICE) 
-	printSubcktDict();
-
-    EFFlatDone(); 
     EFDone();
 
     if (esSpiceF) fclose(esSpiceF);
@@ -1370,6 +1288,7 @@ topVisit(def)
     while (he = HashNext(&def->def_nodes, &hs))
     {
 	sname = (EFNodeName *) HashGetValue(he);
+	if (sname == NULL) continue;
 	snode = sname->efnn_node;
 	if (!(snode->efnode_flags & EF_PORT)) continue;
 	for (nodeName = sname; nodeName != NULL; nodeName = nodeName->efnn_next)
@@ -1381,18 +1300,28 @@ topVisit(def)
     
     if (portmax < 0)
     {
-	/* No port order declared; print them as we see them.	*/
-	/* This shouldn't happen for proper .ext files written	*/
-	/* by the magic extractor.				*/
+	/* No port order declared; print them and number them	*/
+	/* as we encounter them.  This normally happens only	*/
+	/* when writing hierarchical decks for LVS.		*/
+
+	portorder = 0;
 
 	HashStartSearch(&hs);
 	while (he = HashNext(&def->def_nodes, &hs))
 	{
 	    sname = (EFNodeName *) HashGetValue(he);
+	    if (sname == NULL) continue;
 	    snode = sname->efnn_node;
 
-	    if (snode->efnode_name->efnn_node->efnode_flags & EF_PORT)
-		fprintf(esSpiceF, " %s", he->h_key.h_name);
+	    if (snode->efnode_flags & EF_PORT)
+		if (snode->efnode_name->efnn_port < 0)
+		{
+		    // fprintf(esSpiceF, " %s", he->h_key.h_name);
+		    // sname->efnn_port = portorder++;
+		    fprintf(esSpiceF, " %s",
+				nodeSpiceName(snode->efnode_name->efnn_hier));
+		    snode->efnode_name->efnn_port = portorder++;
+		}
 	}
     }
     else
@@ -1417,9 +1346,13 @@ topVisit(def)
 		    portidx = nodeName->efnn_port;
 		    if (portidx == portorder)
 		    {
-			fprintf(esSpiceF, " %s", he->h_key.h_name);
+			// fprintf(esSpiceF, " %s", he->h_key.h_name);
+			fprintf(esSpiceF, " %s",
+				nodeSpiceName(snode->efnode_name->efnn_hier));
 			break;
 		    }
+		    else if (portidx < 0)
+			nodeName->efnn_port = ++portmax;
 		}
 		if (nodeName != NULL) break;
 	    }
@@ -2677,10 +2610,6 @@ devMerge *mkDevMerge(l, w, g, s, d, b, hn, dev)
  * ----------------------------------------------------------------------------
  */
 
-#define	NOT_PARALLEL	0
-#define	PARALLEL	1
-#define	ANTIPARALLEL	2
-
 int
 parallelDevs(f1, f2)
     devMerge *f1, *f2;
