@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extflat/EFbuild.c,v 1.5 2009/01/30 03:51:02 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extflat/EFbuild.c,v 1.6 2010/06/24 12:37:17 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -448,14 +448,15 @@ efBuildEquiv(def, nodeName1, nodeName2)
 
 DevParam *
 efGetDeviceParams(name)
+    char *name;
 {
-   HashEntry *he;
-   DevParam *plist = NULL;
+    HashEntry *he;
+    DevParam *plist = NULL;
 
-   he = HashLookOnly(&efDevParamTable, name);
-   if (he != NULL)
+    he = HashLookOnly(&efDevParamTable, (char *)name);
+    if (he != NULL)
 	plist = (DevParam *)HashGetValue(he);
-   return plist;
+    return plist;
 }
 
 /*
