@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extflat/EFflat.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extflat/EFflat.c,v 1.2 2010/08/25 17:33:56 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -58,7 +58,7 @@ int efFlatGlobHash(HierName *);
 bool efFlatGlobCmp(HierName *, HierName *);
 char *efFlatGlobCopy(HierName *);
 void efFlatGlobError(EFNodeName *, EFNodeName *);
-void efAddNodes(HierContext *, bool);
+int efAddNodes(HierContext *, bool);
 int efAddOneConn(HierContext *, char *, char *, Connection *);
 
 
@@ -143,6 +143,70 @@ EFFlatBuild(name, flags)
 
  return;
 }
+
+/*----------------------------------------------------------------------*/
+/* EFFlatBuildOneLevel --						*/
+/*									*/
+/* EFFlatBuild for a single hierarchical level.  Note, however that	*/
+/* where subcircuits have no extracted components, the hierarchy of	*/
+/* the subcircuit will be traversed and the subcircuit merged into	*/
+/* the root being flattened.						*/
+/*									*/
+/* This routine used for hierarchical extraction.			*/
+/*----------------------------------------------------------------------*/
+
+HierContext *
+EFFlatBuildOneLevel(def)
+    Def *def;		/* root def being flattened */
+{
+    int usecount;
+
+    efFlatRootDef = def;
+
+    /* Keyed by a full HierName */
+    HashInitClient(&efNodeHashTable, INITFLATSIZE, HT_CLIENTKEYS,
+	efHNCompare, (char *(*)()) NULL, efHNHash, (int (*)()) NULL);
+
+    /* Keyed by a pair of HierNames */
+    HashInitClient(&efDistHashTable, INITFLATSIZE, HT_CLIENTKEYS,
+	efHNDistCompare, efHNDistCopy, efHNDistHash, efHNDistKill);
+
+    /* Keyed by pairs of EFNode pointers (i.e., EFCoupleKeys) */
+    HashInit(&efCapHashTable, INITFLATSIZE, HashSize(sizeof (EFCoupleKey)));
+
+    /* Keyed by a string and a HierName */
+    HashInitClient(&efHNUseHashTable, INITFLATSIZE, HT_CLIENTKEYS,
+	efHNUseCompare, (char *(*)()) NULL, efHNUseHash, (int (*)()) NULL);
+
+    /* Circular list of all nodes contains no elements initially */
+    efNodeList.efnode_next = (EFNodeHdr *) &efNodeList;
+    efNodeList.efnode_prev = (EFNodeHdr *) &efNodeList;
+
+    efFlatContext.hc_hierName = (HierName *) NULL;
+    efFlatContext.hc_use = &efFlatRootUse;
+    efFlatContext.hc_trans = GeoIdentityTransform;
+    efFlatContext.hc_x = efFlatContext.hc_y = 0;
+    efFlatRootUse.use_def = efFlatRootDef;
+
+    usecount = 0;
+
+    /* Record all nodes of the next level in the hierarchy */
+    efHierSrUses(&efFlatContext, efAddNodes, (ClientData)FALSE);
+
+    /* Expand all subcells that contain connectivity information but	*/
+    /* no active devices (including those in subcells).			*/
+    efFlatNodesDeviceless(&efFlatContext, &usecount);
+
+    /* Record all local nodes, if they have not already been counted */
+    if (usecount == 0)
+    {
+	efAddNodes(&efFlatContext, FALSE);
+	efAddConns(&efFlatContext);
+    }
+    efFlatGlob();
+
+    return &efFlatContext;
+}
 
 /*
  * ----------------------------------------------------------------------------
@@ -278,6 +342,35 @@ efFlatNodesStdCell(hc)
     return (0);
 }
 
+int
+efFlatNodesDeviceless(hc, cdata)
+    HierContext *hc;
+    ClientData cdata;
+{
+    int *usecount = (int *)cdata;
+    int newcount = 0;
+    Use *use;
+
+    for (use = hc->hc_use->use_def->def_uses; use; use = use->use_next)
+	newcount++;
+
+    /* Recursively flatten uses that have no active devices */
+    if (newcount > 0)
+	efHierSrUses(hc, efFlatNodesDeviceless, (ClientData)&newcount);
+
+    if ((hc->hc_use->use_def->def_devs == NULL) && (newcount == 0))
+    {
+	/* Add all our own nodes to the table */
+	efAddNodes(hc, TRUE);
+
+	/* Process our own connections and adjustments */
+	efAddConns(hc);
+
+	(*usecount)--;
+    }
+    return (0);
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -297,7 +390,7 @@ efFlatNodesStdCell(hc)
  * ----------------------------------------------------------------------------
  */
 
-void
+int
 efAddNodes(hc, stdcell)
     HierContext *hc;
     bool stdcell;
@@ -409,6 +502,7 @@ efAddNodes(hc, stdcell)
 	    }
 	}
     }
+    return 0;
 }
 
 /*
