@@ -1780,15 +1780,13 @@ extTransTileFunc(tile, pNum)
      * Visit each segment of the perimeter of this tile that
      * that borders on something of a different type.
      */
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
         loctype = (SplitSide(tile)) ? SplitRightType(tile): SplitLeftType(tile);
 	// return (0); 	/* Hack alert!  We must properly handle diagonals! */
     }
     else
-#endif
-    loctype = TiGetTypeExact(tile);
+	loctype = TiGetTypeExact(tile);
 
     mask = ExtCurStyle->exts_transConn[loctype];
     TTMaskCom(&mask);
@@ -1970,14 +1968,12 @@ extAnnularTileFunc(tile, pNum)
      * Visit each segment of the perimeter of this tile that
      * that borders on something of a different type.
      */
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
         loctype = (SplitSide(tile)) ? SplitRightType(tile): SplitLeftType(tile);
     }
     else
-#endif
-    loctype = TiGetTypeExact(tile);
+	loctype = TiGetTypeExact(tile);
 
     mask = ExtCurStyle->exts_transConn[loctype];
     TTMaskCom(&mask);
@@ -2021,14 +2017,12 @@ extResistorTileFunc(tile, pNum)
      * Visit each segment of the perimeter of this tile that
      * that borders on something of a different type.
      */
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
         loctype = (SplitSide(tile)) ? SplitRightType(tile): SplitLeftType(tile);
     }
     else
-#endif
-    loctype = TiGetTypeExact(tile);
+	loctype = TiGetTypeExact(tile);
 
     mask = ExtCurStyle->exts_transConn[loctype];
     TTMaskSetMask(&mask, &ExtCurStyle->exts_transSDTypes[loctype][0]);
@@ -2056,45 +2050,31 @@ extSpecialPerimFunc(bp, sense)
     LinkedBoundary *newBound, *lb, *lastlb;
     bool needSurvey;
 
-#ifdef NONMANHATTAN
     /* Note that extEnumTilePerim() assumes for the non-Manhattan case	*/
     /* that non-Manhattan tiles should be incorporated into the device	*/
     /* gate for purposes of computing effective length and width.  In	*/
     /* most cases this will be only a slight deviation from the true	*/
     /* result.								*/
 
-    if (IsSplit(bp->b_inside))
+    switch (bp->b_direction)
     {
-	switch (bp->b_direction)
-	{
-	    case BD_TOP:
-		tinside = TiGetBottomType(bp->b_inside);
-		toutside = TiGetBottomType(bp->b_outside);
-		break;
-	    case BD_BOTTOM:
-		tinside = TiGetTopType(bp->b_inside);
-		toutside = TiGetTopType(bp->b_outside);
-		break;
-	    case BD_RIGHT:
-		tinside = TiGetLeftType(bp->b_inside);
-		toutside = TiGetLeftType(bp->b_outside);
-		break;
-	    case BD_LEFT:
-		tinside = TiGetRightType(bp->b_inside);
-		toutside = TiGetRightType(bp->b_outside);
-		break;
-	}
+	case BD_TOP:
+	    tinside = TiGetTopType(bp->b_inside);
+	    toutside = TiGetBottomType(bp->b_outside);
+	    break;
+	case BD_BOTTOM:
+	    tinside = TiGetBottomType(bp->b_inside);
+	    toutside = TiGetTopType(bp->b_outside);
+	    break;
+	case BD_RIGHT:
+	    tinside = TiGetRightType(bp->b_inside);
+	    toutside = TiGetLeftType(bp->b_outside);
+	    break;
+	case BD_LEFT:
+	    tinside = TiGetLeftType(bp->b_inside);
+	    toutside = TiGetRightType(bp->b_outside);
+	    break;
     }
-    else
-    {
-	tinside = TiGetTypeExact(bp->b_inside);
-	toutside = TiGetTypeExact(bp->b_outside);
-    }
-
-#else
-    tinside = TiGetType(bp->b_inside);
-    toutside = TiGetType(bp->b_outside);
-#endif
 
     /* Check all terminal classes for a matching type */
     needSurvey = FALSE;
@@ -2390,7 +2370,6 @@ Tile *extNodeToTile(np, et)
     GOTOPOINT(tp, &np->nreg_ll);
     myplane->pl_hint = tp;
 
-#ifdef NONMANHATTAN
     if (IsSplit(tp))
     {
 	TileType tpt = TiGetTypeExact(tp);
@@ -2399,7 +2378,6 @@ Tile *extNodeToTile(np, et)
 	else
 	    TiSetBody(tp, tpt | TT_SIDE);
     }
-#endif
 
     return tp;
 }
@@ -2433,7 +2411,6 @@ extSetNodeNum(reg, plane, tile)
 {
     TileType type;
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
 	/* Only consider split tiles if the lower-left-hand corner      */
@@ -2447,7 +2424,6 @@ extSetNodeNum(reg, plane, tile)
 	    return;
     }
     else
-#endif
 	type = TiGetType(tile);
 
     if ((plane < reg->lreg_pnum) || (reg->lreg_type & TT_DIAGONAL))
@@ -2509,11 +2485,9 @@ extTransFirst(tile, arg)
     reg->treg_area = 0;
     reg->treg_tile = tile;
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
 	reg->treg_type = SplitSide(tile) ? SplitRightType(tile) : SplitLeftType(tile);
     else
-#endif
 	reg->treg_type = TiGetTypeExact(tile);
 
     /* Prepend it to the region list */
@@ -2532,7 +2506,6 @@ extTransEach(tile, pNum, arg)
     TransRegion *reg = (TransRegion *) arg->fra_region;
     int area = TILEAREA(tile);
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile)) area /= 2;	/* Split tiles are 1/2 area! */
     else if (IsSplit(reg->treg_tile))
     {
@@ -2540,7 +2513,6 @@ extTransEach(tile, pNum, arg)
 	reg->treg_tile = tile;
 	reg->treg_type = TiGetTypeExact(tile);
     }
-#endif
 
     /* Don't double-count area on contacts (added by Tim 1/9/07) */
     if (pNum == DBPlane(TiGetType(tile)))
@@ -2630,13 +2602,11 @@ extNodeAreaFunc(tile, arg)
     Rect r;
     PlaneAndArea pla;
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
 	type = (SplitSide(tile)) ? SplitRightType(tile) : SplitLeftType(tile);
 	if (type == TT_SPACE) return 0;		/* Should not happen */
     }
-#endif
 
     /* Compute the resistance for the previous region */
     if (old = (NodeRegion *) arg->fra_region)
@@ -2679,15 +2649,13 @@ extNodeAreaFunc(tile, arg)
 	if (DebugIsSet(extDebugID, extDebNeighbor))
 	    extShowTile(tile, "neighbor", 1);
 
-#ifdef NONMANHATTAN
         if (IsSplit(tile))
         {           
             type = (SplitSide(tile)) ? SplitRightType(tile):
                         SplitLeftType(tile);
         }           
         else        
-#endif              
-        type = TiGetTypeExact(tile);
+            type = TiGetTypeExact(tile);
 
 	/* Contacts are replaced by their residues when calculating */
 	/* area/perimeter capacitance and resistance.		    */
@@ -2720,15 +2688,12 @@ extNodeAreaFunc(tile, arg)
 	}
 	else area = TILEAREA(tile);
 
-#ifdef NONMANHATTAN
 	if (IsSplit(tile)) area /= 2;	/* Split tiles are 1/2 area! */
-#endif
 
 	if (resistClass != -1)
 	    extResistArea[resistClass] += area;
 	reg->nreg_cap += area * ExtCurStyle->exts_areaCap[residue];
 
-#ifdef NONMANHATTAN
 	/* Compute perimeter of nonManhattan edges */
 	if (IsSplit(tile))
 	{
@@ -2751,8 +2716,6 @@ extNodeAreaFunc(tile, arg)
 		extResistPerim[resistClass] += len;
 	}
 
-#endif
-
 	/*
 	 * Walk along all four sides of tile.
 	 * Sum perimeter capacitance as we go.
@@ -2763,9 +2726,7 @@ extNodeAreaFunc(tile, arg)
 	/* Top */
 topside:
 
-#ifdef NONMANHATTAN
 	if (IsSplit(tile) && (SplitSide(tile) ^ SplitDirection(tile))) goto leftside;
-#endif
 
 	for (tp = RT(tile); RIGHT(tp) > LEFT(tile); tp = BL(tp))
 	{
@@ -2778,7 +2739,6 @@ topside:
 		len = EDGENULL(&r) ? 0 : r.r_xtop - r.r_xbot;
 	    }
 	    else len = MIN(RIGHT(tile), RIGHT(tp)) - MAX(LEFT(tile), LEFT(tp));
-#ifdef NONMANHATTAN
             if (IsSplit(tp))
 	    {
         	t = SplitBottomType(tp);
@@ -2788,7 +2748,6 @@ topside:
 		}
 	    }
             else
-#endif
 	    {
 		t = TiGetTypeExact(tp);
 		if (tp->ti_client == extUnInit && TTMaskHasType(mask, t))
@@ -2806,9 +2765,7 @@ topside:
 	/* Left */
 leftside:
 
-#ifdef NONMANHATTAN
 	if (IsSplit(tile) && SplitSide(tile)) goto bottomside;
-#endif
 
 	for (tp = BL(tile); BOTTOM(tp) < TOP(tile); tp = RT(tp))
 	{
@@ -2821,7 +2778,6 @@ leftside:
 		len = EDGENULL(&r) ? 0 : r.r_ytop - r.r_ybot;
 	    }
 	    else len = MIN(TOP(tile), TOP(tp)) - MAX(BOTTOM(tile), BOTTOM(tp));
-#ifdef NONMANHATTAN
             if (IsSplit(tp))
 	    {
                 t = SplitRightType(tp);
@@ -2831,7 +2787,6 @@ leftside:
 		}
 	    }
             else
-#endif
 	    {
 		t = TiGetTypeExact(tp);
 		if (tp->ti_client == extUnInit && TTMaskHasType(mask, t))
@@ -2849,10 +2804,8 @@ leftside:
 	/* Bottom */
 bottomside:
 
-#ifdef NONMANHATTAN
 	if (IsSplit(tile) && (!(SplitSide(tile) ^ SplitDirection(tile))))
 	    goto rightside;
-#endif
 
 	for (tp = LB(tile); LEFT(tp) < RIGHT(tile); tp = TR(tp))
 	{
@@ -2865,7 +2818,6 @@ bottomside:
 		len = EDGENULL(&r) ? 0 : r.r_xtop - r.r_xbot;
 	    }
 	    else len = MIN(RIGHT(tile), RIGHT(tp)) - MAX(LEFT(tile), LEFT(tp));
-#ifdef NONMANHATTAN
             if (IsSplit(tp))
 	    {
                 t = SplitTopType(tp);
@@ -2875,7 +2827,6 @@ bottomside:
 		}
 	    }
             else
-#endif
 	    {
 		t = TiGetTypeExact(tp);
 		if (tp->ti_client == extUnInit && TTMaskHasType(mask, t))
@@ -2893,9 +2844,7 @@ bottomside:
 	/* Right */
 rightside:
 
-#ifdef NONMANHATTAN
 	if (IsSplit(tile) && !SplitSide(tile)) goto donesides;
-#endif
 
 	for (tp = TR(tile); TOP(tp) > BOTTOM(tile); tp = LB(tp))
 	{
@@ -2908,7 +2857,6 @@ rightside:
 		len = EDGENULL(&r) ? 0 : r.r_ytop - r.r_ybot;
 	    }
 	    else len = MIN(TOP(tile), TOP(tp)) - MAX(BOTTOM(tile), BOTTOM(tp));
-#ifdef NONMANHATTAN
             if (IsSplit(tp))
 	    {
                 t = SplitLeftType(tp);
@@ -2918,7 +2866,6 @@ rightside:
 		}
 	    }
             else
-#endif
 	    {
 		t = TiGetTypeExact(tp);
 		if (tp->ti_client == extUnInit && TTMaskHasType(mask, t))
@@ -2954,7 +2901,6 @@ donesides:
 
 		    if (tp->ti_client != extUnInit) continue;
 
-#ifdef NONMANHATTAN
 		    /* tp and tile should have the same geometry for a contact */
 		    if (IsSplit(tile) && IsSplit(tp))
 		    {           
@@ -2990,7 +2936,6 @@ donesides:
 			}
 		    }
 		    else
-#endif              
 		    {
 			t = TiGetTypeExact(tp);
 			if (TTMaskHasType(mask, t))
