@@ -20,7 +20,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extract/ExtHard.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extract/ExtHard.c,v 1.2 2010/06/24 12:37:17 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -98,14 +98,12 @@ extLabEach(tile, pNum, arg)
 {
     TransRegion *reg = (TransRegion *) arg->fra_region;
 
-#ifdef NONMANHATTAN
     /* Avoid setting the region's tile pointer to a split tile if we can */
     if (IsSplit(reg->treg_tile) && !IsSplit(tile))
     {
 	reg->treg_tile = tile;
 	reg->treg_area = pNum;
     }
-#endif
 
     if (reg->treg_area == DBNumPlanes) reg->treg_area = pNum;
     extSetNodeNum((LabRegion *)reg, pNum, tile);
