@@ -20,7 +20,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extract/ExtHier.c,v 1.2 2009/05/30 03:14:00 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extract/ExtHier.c,v 1.3 2010/06/24 12:37:17 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -130,14 +130,12 @@ extHierConnectFunc1(oneTile, ha)
     ha->hierOneTile = oneTile;
     ha->hierType = TiGetTypeExact(oneTile);
 
-#ifdef NONMANHATTAN
     if (IsSplit(oneTile))
     {
 	rtype = ha->hierType;
 	ha->hierType = (rtype & TT_SIDE) ? SplitRightType(oneTile) :
 		SplitLeftType(oneTile);
     }  
-#endif
 
     connected = &(ExtCurStyle->exts_nodeConn[ha->hierType]);
     TITORECT(oneTile, &r);
@@ -149,14 +147,12 @@ extHierConnectFunc1(oneTile, ha)
 	TTMaskAndMask3(&mask, connected, &DBPlaneTypes[i]);
 	if (!TTMaskIsZero(&mask))
 	{
-#ifdef NONMANHATTAN
 	    if (IsSplit(oneTile))
 		DBSrPaintNMArea((Tile *) NULL, cumDef->cd_planes[i],
 			rtype, &r,
 			((i == ha->hierPNum) ? &DBAllButSpaceBits : connected),
 			extHierConnectFunc2, (ClientData) ha);
 	    else
-#endif
 		DBSrPaintArea((Tile *) NULL, cumDef->cd_planes[i], &r,
 			((i == ha->hierPNum) ? &DBAllButSpaceBits : connected),
 			extHierConnectFunc2, (ClientData) ha);
@@ -215,10 +211,8 @@ extHierConnectFunc2(cum, ha)
 
     ttype = TiGetTypeExact(cum);
 
-#ifdef NONMANHATTAN
     if (IsSplit(cum))
 	ttype = (ttype & TT_SIDE) ? SplitRightType(cum) : SplitLeftType(cum);
-#endif
 
     if (extConnectsTo(ha->hierType, ttype, ExtCurStyle->exts_nodeConn))
     {
