@@ -19,7 +19,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extract/ExtPerim.c,v 1.2 2009/06/01 17:18:10 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extract/ExtPerim.c,v 1.4 2010/08/10 00:18:46 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -67,6 +67,12 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
  *	None directly, but applies the client's filter function
  *	to each qualifying segment of the boundary.
  *
+ * Note:
+ *	The width/length calculation method is manhattan-only.  So this
+ *	routine is pseudo-manhattan.  It computes the true non-manhattan
+ *	perimeter, but calls the function on the perimeter tiles as if
+ *	the whole tile is the transistor type.
+ *
  * Non-interruptible.
  *
  * ----------------------------------------------------------------------------
@@ -80,19 +86,22 @@ extEnumTilePerim(tpIn, mask, pNum, func, cdata)
     int (*func)();
     ClientData cdata;
 {
+    TileType origType;
     Tile *tpOut;
     u_int perimLength;
     Boundary b;
+    u_char sides = 0;
 
     b.b_inside = tpIn;
     b.b_plane = pNum;
     perimLength = 0;
 
-#ifdef NONMANHATTAN
-	/* Diagonal */
+    /* Diagonal */
     if (IsSplit(tpIn))
     {
 	TileType otype = (SplitSide(tpIn)) ? SplitLeftType(tpIn): SplitRightType(tpIn);
+	TileType itype = (SplitSide(tpIn)) ? SplitRightType(tpIn): SplitLeftType(tpIn);
+	origType = TiGetTypeExact(tpIn);
 	if (TTMaskHasType(&mask, otype))
 	{
 	    int width = RIGHT(tpIn) - LEFT(tpIn);
@@ -100,10 +109,14 @@ extEnumTilePerim(tpIn, mask, pNum, func, cdata)
 	    perimLength = width * width + height * height;
 	    perimLength = (int)sqrt((double)perimLength);
 	}
+	sides = (SplitSide(tpIn)) ? BD_LEFT : BD_RIGHT;
+	sides |= (SplitSide(tpIn) == SplitDirection(tpIn)) ? BD_BOTTOM : BD_TOP;
+	TiSetBody(tpIn, itype);
     }
-#endif
+    else
+	sides = 0;
 
-	/* Top */
+    /* Top */
     b.b_segment.r_ybot = b.b_segment.r_ytop = TOP(tpIn);
     b.b_direction = BD_TOP;
     for (tpOut = RT(tpIn); RIGHT(tpOut) > LEFT(tpIn); tpOut = BL(tpOut))
@@ -113,12 +126,12 @@ extEnumTilePerim(tpIn, mask, pNum, func, cdata)
 	    b.b_segment.r_xbot = MAX(LEFT(tpIn), LEFT(tpOut));
 	    b.b_segment.r_xtop = MIN(RIGHT(tpIn), RIGHT(tpOut));
 	    b.b_outside = tpOut;
-	    perimLength += BoundaryLength(&b);
+	    if (!(sides & BD_TOP)) perimLength += BoundaryLength(&b);
 	    if (func) (*func)(&b, cdata);
 	}
     }
 
-	/* Bottom */
+    /* Bottom */
     b.b_segment.r_ybot = b.b_segment.r_ytop = BOTTOM(tpIn);
     b.b_direction = BD_BOTTOM;
     for (tpOut = LB(tpIn); LEFT(tpOut) < RIGHT(tpIn); tpOut = TR(tpOut))
@@ -128,12 +141,12 @@ extEnumTilePerim(tpIn, mask, pNum, func, cdata)
 	    b.b_segment.r_xbot = MAX(LEFT(tpIn), LEFT(tpOut));
 	    b.b_segment.r_xtop = MIN(RIGHT(tpIn), RIGHT(tpOut));
 	    b.b_outside = tpOut;
-	    perimLength += BoundaryLength(&b);
+	    if (!(sides & BD_BOTTOM)) perimLength += BoundaryLength(&b);
 	    if (func) (*func)(&b, cdata);
 	}
     }
 
-	/* Left */
+    /* Left */
     b.b_segment.r_xbot = b.b_segment.r_xtop = LEFT(tpIn);
     b.b_direction = BD_LEFT;
     for (tpOut = BL(tpIn); BOTTOM(tpOut) < TOP(tpIn); tpOut = RT(tpOut))
@@ -143,12 +156,12 @@ extEnumTilePerim(tpIn, mask, pNum, func, cdata)
 	    b.b_segment.r_ybot = MAX(BOTTOM(tpIn), BOTTOM(tpOut));
 	    b.b_segment.r_ytop = MIN(TOP(tpIn), TOP(tpOut));
 	    b.b_outside = tpOut;
-	    perimLength += BoundaryLength(&b);
+	    if (!(sides & BD_LEFT)) perimLength += BoundaryLength(&b);
 	    if (func) (*func)(&b, cdata);
 	}
     }
 
-	/* Right */
+    /* Right */
     b.b_segment.r_xbot = b.b_segment.r_xtop = RIGHT(tpIn);
     b.b_direction = BD_RIGHT;
     for (tpOut = TR(tpIn); TOP(tpOut) > BOTTOM(tpIn); tpOut = LB(tpOut))
@@ -158,10 +171,13 @@ extEnumTilePerim(tpIn, mask, pNum, func, cdata)
 	    b.b_segment.r_ybot = MAX(BOTTOM(tpIn), BOTTOM(tpOut));
 	    b.b_segment.r_ytop = MIN(TOP(tpIn), TOP(tpOut));
 	    b.b_outside = tpOut;
-	    perimLength += BoundaryLength(&b);
+	    if (!(sides & BD_RIGHT)) perimLength += BoundaryLength(&b);
 	    if (func) (*func)(&b, cdata);
 	}
     }
 
+    if (sides != 0)
+	TiSetBody(tpIn, origType);
+
     return (perimLength);
 }
