@@ -142,7 +142,7 @@ static keydesc keyTable[] = {
 "resistance-scalefactor",
 
     "sidehalo",		SIDEHALO,	2,	2,
-"halo(lambda)",
+"halo",
 
     "sideoverlap",	SIDEOVERLAP,	5,	6,
 "intypes outtypes ovtypes capacitance [shieldtypes]",
@@ -151,7 +151,7 @@ static keydesc keyTable[] = {
 "intypes outtypes neartypes fartypes capacitance",
 
     "step",		STEP,		2,	2,
-"size(lambda)",
+"size",
 
     "style",		STYLE,		2,	4,
 "stylename",
@@ -1868,7 +1868,8 @@ ExtTechLine(sectionName, argc, argv)
 
 	    /* No limit on arguments in DEV_SUBCKT! */
 	    /* And. . . check DEV_RSUBCKT later, after parsing parameter names */
-	    switch (dv->k_key)
+	    class = dv->k_key;
+	    switch (class)
 	    {
 		case DEV_SUBCKT:
 		case DEV_RSUBCKT:
@@ -1904,7 +1905,7 @@ ExtTechLine(sectionName, argc, argv)
 			TTMaskAndMask3(&termtypes[2], &termtypes[0], &termtypes[1]);
 
 			if (TTMaskEqual(&termtypes[0], &termtypes[1]))
-			    termtypes[1] = DBSpaceBits;	/* Make is symmetric */
+			    termtypes[1] = DBSpaceBits;	/* Make it symmetric */
 			else if (!TTMaskIsZero(&termtypes[2]))
 			{
 			    TechError("Device mosfet %s has overlapping drain"
@@ -1918,6 +1919,7 @@ ExtTechLine(sectionName, argc, argv)
 			if (argc > 8) gscap = aToCap(argv[8]);
 			if (argc > 9) gccap = aToCap(argv[9]);
 			nterm = 2;
+			class = DEV_ASYMMETRIC;
 		    }
 		    else
 		    {
@@ -2008,6 +2010,8 @@ ExtTechLine(sectionName, argc, argv)
 			DBTechNoisyNameMask(argv[iterm], &termtypes[i - iterm]);
 		    termtypes[nterm] = DBSpaceBits;
 
+		    if (nterm == 0) i++;
+
 		    if (argc > i)
 			DBTechNoisyNameMask(argv[i], &subsTypes); /* substrate */
 		    if (argc > (i + 1)) subsName = argv[i + 1];
@@ -2071,7 +2075,7 @@ ExtTechLine(sectionName, argc, argv)
 		    ExtCurStyle->exts_transSDCount[t] = nterm;
 		    ExtCurStyle->exts_transSDCap[t] = gscap;
 		    ExtCurStyle->exts_transGateCap[t] = gccap;
-		    ExtCurStyle->exts_deviceClass[t] = dv->k_key;
+		    ExtCurStyle->exts_deviceClass[t] = class;
 		    ExtCurStyle->exts_transName[t] =
 			    StrDup((char **) NULL, transName);
 		    ExtCurStyle->exts_transSubstrateName[t] =
