@@ -19,7 +19,7 @@
 
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/graphics/grClip.c,v 1.3 2010/05/11 19:28:53 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/graphics/grClip.c,v 1.4 2010/06/24 12:37:18 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -584,158 +584,146 @@ GrBoxOutline(tile, tilesegs)
     *tilesegs = NULL;
     TiToRect(tile, &rect);
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile) && SplitSide(tile))
 	isolate |= 0x1;
     else
     {
-#endif
-    ttype = TiGetLeftType(tile);   /* = TiGetType when NONMANHATTAN not def'd */
-
-    edgeBot = rect.r_ybot;
-    sense = TRUE;
-    for (tpleft = BL(tile); BOTTOM(tpleft) < rect.r_ytop; tpleft = RT(tpleft))
-    {
-	if (TiGetRightType(tpleft) != ttype)
+	ttype = TiGetLeftType(tile);
+	edgeBot = rect.r_ybot;
+	sense = TRUE;
+	for (tpleft = BL(tile); BOTTOM(tpleft) < rect.r_ytop; tpleft = RT(tpleft))
 	{
-	    if (!sense)
+	    if (TiGetRightType(tpleft) != ttype)
 	    {
-		edgeBot = BOTTOM(tpleft);
-		if (TOP(tpleft) >= rect.r_ytop)
-		    grAddSegment(rect.r_xbot, edgeBot, rect.r_xbot, rect.r_ytop,
+		if (!sense)
+		{
+		    edgeBot = BOTTOM(tpleft);
+		    if (TOP(tpleft) >= rect.r_ytop)
+			grAddSegment(rect.r_xbot, edgeBot, rect.r_xbot, rect.r_ytop,
+					tilesegs);
+		    sense = TRUE;
+		}
+	    }
+	    else
+	    {
+		if (sense)
+		{
+		    edgeTop = BOTTOM(tpleft);
+		    if (edgeTop > edgeBot)
+			grAddSegment(rect.r_xbot, edgeBot, rect.r_xbot, edgeTop,
 				tilesegs);
-		sense = TRUE;
+		    isolate |= 0x1;
+		    sense = FALSE;
+		}
 	    }
 	}
-	else
-	{
-	    if (sense)
-	    {
-		edgeTop = BOTTOM(tpleft);
-		if (edgeTop > edgeBot)
-		    grAddSegment(rect.r_xbot, edgeBot, rect.r_xbot, edgeTop,
-				tilesegs);
-		isolate |= 0x1;
-		sense = FALSE;
-	    }
-	}
-    }
-
-#ifdef NONMANHATTAN
     }
     if (IsSplit(tile) && !SplitSide(tile))
 	isolate |= 0x2;
     else
     {
 	ttype = TiGetRightType(tile);
-#endif
-    edgeTop = rect.r_ytop;
-    sense = TRUE;
-    for (tpright = TR(tile); TOP(tpright) > rect.r_ybot; tpright = LB(tpright))
-    {
-	if (TiGetLeftType(tpright) != ttype)
+	edgeTop = rect.r_ytop;
+	sense = TRUE;
+	for (tpright = TR(tile); TOP(tpright) > rect.r_ybot; tpright = LB(tpright))
 	{
-	    if (!sense)
+	    if (TiGetLeftType(tpright) != ttype)
 	    {
-		edgeTop = TOP(tpright);
-		if (BOTTOM(tpright) <= rect.r_ybot)
-		    grAddSegment(rect.r_xtop, rect.r_ybot, rect.r_xtop, edgeTop,
-				tilesegs);
-		sense = TRUE;
+		if (!sense)
+		{
+		    edgeTop = TOP(tpright);
+		    if (BOTTOM(tpright) <= rect.r_ybot)
+			grAddSegment(rect.r_xtop, rect.r_ybot, rect.r_xtop, edgeTop,
+					tilesegs);
+		    sense = TRUE;
+		}
 	    }
-	}
-	else
-	{
-	    if (sense)
+	    else
 	    {
-		edgeBot = TOP(tpright);
-		if (edgeBot < edgeTop)
-		    grAddSegment(rect.r_xtop, edgeBot, rect.r_xtop, edgeTop,
-				tilesegs);
-		isolate |= 0x2;
-		sense = FALSE;
+		if (sense)
+		{
+		    edgeBot = TOP(tpright);
+		    if (edgeBot < edgeTop)
+			grAddSegment(rect.r_xtop, edgeBot, rect.r_xtop, edgeTop,
+					tilesegs);
+		    isolate |= 0x2;
+		    sense = FALSE;
+		}
 	    }
 	}
     }
 
-#ifdef NONMANHATTAN
-    }
     if (IsSplit(tile) &&
 		(SplitSide(tile) == SplitDirection(tile)))
 	isolate |= 0x4;
     else
     {
 	ttype = TiGetBottomType(tile);
-#endif
-    edgeLeft = rect.r_xbot;
-    sense = TRUE;
-    for (tpbot = LB(tile); LEFT(tpbot) < rect.r_xtop; tpbot = TR(tpbot))
-    {
-	if (TiGetTopType(tpbot) != ttype)
+	edgeLeft = rect.r_xbot;
+	sense = TRUE;
+	for (tpbot = LB(tile); LEFT(tpbot) < rect.r_xtop; tpbot = TR(tpbot))
 	{
-	    if (!sense)
+	    if (TiGetTopType(tpbot) != ttype)
 	    {
-		edgeLeft = LEFT(tpbot);
-		if (RIGHT(tpbot) >= rect.r_xtop)
-		    grAddSegment(edgeLeft, rect.r_ybot, rect.r_xtop, rect.r_ybot,
-				tilesegs);
-		sense = TRUE;
+		if (!sense)
+		{
+		    edgeLeft = LEFT(tpbot);
+		    if (RIGHT(tpbot) >= rect.r_xtop)
+			grAddSegment(edgeLeft, rect.r_ybot, rect.r_xtop, rect.r_ybot,
+					tilesegs);
+		    sense = TRUE;
+		}
 	    }
-	}
-	else
-	{
-	    if (sense)
+	    else
 	    {
-		edgeRight = LEFT(tpbot);
-		if (edgeRight > edgeLeft)
-		    grAddSegment(edgeLeft, rect.r_ybot, edgeRight, rect.r_ybot,
-				tilesegs);
-		isolate |= 0x4;
-		sense = FALSE;
+		if (sense)
+		{
+		    edgeRight = LEFT(tpbot);
+		    if (edgeRight > edgeLeft)
+			grAddSegment(edgeLeft, rect.r_ybot, edgeRight, rect.r_ybot,
+					tilesegs);
+		    isolate |= 0x4;
+		    sense = FALSE;
+		}
 	    }
 	}
     }
 
-#ifdef NONMANHATTAN
-    }
     if (IsSplit(tile) &&
 		(SplitSide(tile) != SplitDirection(tile)))
 	isolate |= 0x8;
     else
     {
 	ttype = TiGetTopType(tile);
-#endif
-    edgeRight = rect.r_xtop;
-    sense = TRUE;
-    for (tptop = RT(tile); RIGHT(tptop) > rect.r_xbot; tptop = BL(tptop))
-    {
-	if (TiGetBottomType(tptop) != ttype)
+	edgeRight = rect.r_xtop;
+	sense = TRUE;
+	for (tptop = RT(tile); RIGHT(tptop) > rect.r_xbot; tptop = BL(tptop))
 	{
-	    if (!sense)
+	    if (TiGetBottomType(tptop) != ttype)
 	    {
-		edgeRight = RIGHT(tptop);
-		if (LEFT(tptop) <= rect.r_xbot)
-		    grAddSegment(rect.r_xbot, rect.r_ytop, edgeRight, rect.r_ytop,
-				tilesegs);
-		sense = TRUE;
+		if (!sense)
+		{
+		    edgeRight = RIGHT(tptop);
+		    if (LEFT(tptop) <= rect.r_xbot)
+			grAddSegment(rect.r_xbot, rect.r_ytop, edgeRight, rect.r_ytop,
+					tilesegs);
+		    sense = TRUE;
+		}
 	    }
-	}
-	else
-	{
-	    if (sense)
+	    else
 	    {
-		edgeLeft = RIGHT(tptop);
-		if (edgeLeft < edgeRight)
-		    grAddSegment(edgeLeft, rect.r_ytop, edgeRight, rect.r_ytop,
-				tilesegs);
-		isolate |= 0x8;
-		sense = FALSE;
+		if (sense)
+		{
+		    edgeLeft = RIGHT(tptop);
+		    if (edgeLeft < edgeRight)
+			grAddSegment(edgeLeft, rect.r_ytop, edgeRight, rect.r_ytop,
+					tilesegs);
+		    isolate |= 0x8;
+		    sense = FALSE;
+		}
 	    }
 	}
     }
-#ifdef NONMANHATTAN
-    }
-#endif
 
     if (isolate == 0)	/* Common case */
 	return TRUE;
@@ -797,12 +785,10 @@ GrBox(MagWindow *mw, Transform *trans, Tile *tile)
     r.r_ytop = TOP(tile);
 
     GeoTransRect(trans, &r, &r2);
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
 	WindSurfaceToScreenNoClip(mw, &r2, &r);
     else
-#endif
-    WindSurfaceToScreen(mw, &r2, &r);
+	WindSurfaceToScreen(mw, &r2, &r);
 
     GR_CHECK_LOCK();
     if (!grDriverInformed) grInformDriver();
@@ -818,7 +804,6 @@ GrBox(MagWindow *mw, Transform *trans, Tile *tile)
     for (ob = grCurObscure; ob != NULL; ob = ob->r_next)
 	needObscure |= GEO_TOUCH(&r, &(ob->r_r));
 
-#ifdef NONMANHATTAN
     /* Nonmanhattan tiles: */
     /* Expects one of the two tile types to be masked out before */
     /* this procedure is called.                                 */
@@ -848,26 +833,21 @@ GrBox(MagWindow *mw, Transform *trans, Tile *tile)
     }
     else
     {
-#endif
 
-    /* do solid areas (same as GrFastBox) */
+	/* do solid areas (same as GrFastBox) */
 
-    if ((grCurFill == GR_STSOLID) || 
-	(grCurFill == GR_STSTIPPLE))
-    {
-	/* We have a filled area to deal with */
-	clipr = r;
-	if (needClip)
-	    GeoClip(&clipr, &grCurClip);
-	if (needObscure)
-	    grObsBox(&clipr);
-	else
-	    (void) (*grFillRectPtr)(&clipr);
-    } 
-
-#ifdef NONMANHATTAN
+	if ((grCurFill == GR_STSOLID) || (grCurFill == GR_STSTIPPLE))
+	{
+	    /* We have a filled area to deal with */
+	    clipr = r;
+	    if (needClip)
+		GeoClip(&clipr, &grCurClip);
+	    if (needObscure)
+		grObsBox(&clipr);
+	    else
+		(void) (*grFillRectPtr)(&clipr);
+	} 
     }
-#endif
 
     /* return if outline is too small to be worth drawing */
 
@@ -945,7 +925,6 @@ GrBox(MagWindow *mw, Transform *trans, Tile *tile)
 		freeMagic(segptr);
 	    }
 
-#ifdef NONMANHATTAN
 	    /* For non-manhattan tiles, the manhattan parts of the	*/
 	    /* boundary have already been drawn.  The diagonal boundary */
 	    /* is guaranteed to be continuous by definition, and it has	*/
@@ -973,7 +952,6 @@ GrBox(MagWindow *mw, Transform *trans, Tile *tile)
 				polyp[0].p_x, polyp[0].p_y);
 		}
 	    }
-#endif
 	}
     }
 }
@@ -1154,8 +1132,6 @@ GrDrawFastBox(prect, scale)
     }
 }
 
-#ifdef NONMANHATTAN
-
 /*---------------------------------------------------------
  * GrClipTriangle:
  *	Returns an array of points representing a clipped
@@ -1570,7 +1546,6 @@ GrFillPolygon(polyp, np)
     }
 }
 
-#endif /* NONMANHATTAN */
 
 /*---------------------------------------------------------
  * GrClipBox:
