@@ -32,6 +32,7 @@
 #include "utils/utils.h"
 #include "utils/hash.h"
 #include "dbwind/dbwind.h"
+#include "database/fonts.h"
 #include "grX11Int.h"
 
 /* locals */
@@ -706,7 +707,7 @@ grx11FontText(text, font, size, rotate, pos, clip, obscure)
 	    xp[j].y = charbbox.r_ytop - xp[j].y;
 	}
 
-	pxm = XCreatePixmap(grXdpy, grCurrent.windowid, w, h, 1);
+	pxm = XCreatePixmap(grXdpy, grCurrent.window, w, h, 1);
 
 	if (fontgc == (GC)NULL)
 	{
@@ -736,7 +737,7 @@ grx11FontText(text, font, size, rotate, pos, clip, obscure)
 
 	XSetClipMask(grXdpy, grGCText, pxm);
 	XSetClipOrigin(grXdpy, grGCText, locoffset.p_x, locoffset.p_y);
-	XFillRectangle(grXdpy, grCurrent.windowid, grGCText, locoffset.p_x,
+	XFillRectangle(grXdpy, grCurrent.window, grGCText, locoffset.p_x,
 		locoffset.p_y, w, h);
 
 	lpos.p_x += coffset->p_x;
