@@ -84,7 +84,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/mzrouter/mzBlock.c,v 1.16 2006/10/21 04:36:07 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/mzrouter/mzBlock.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -841,7 +841,8 @@ mzBuildDestAreaBlocks()
 {
     int mzDestAreaFunc();
     int mzDestWalksFunc();
-    int mzCWalksFunc();
+    int mzLRCWalksFunc();
+    int mzUDCWalksFunc();
     SearchContext scx;
 
     /* initialize global walk list */
@@ -874,7 +875,10 @@ mzBuildDestAreaBlocks()
 			     0, mzDestWalksFunc, (ClientData) NULL);
 
     (void) DBTreeSrTiles(&scx, &DBAllButSpaceAndDRCBits, 
-			     0, mzCWalksFunc, (ClientData) NULL);
+			     0, mzUDCWalksFunc, (ClientData) NULL);
+
+    (void) DBTreeSrTiles(&scx, &DBAllButSpaceAndDRCBits, 
+			     0, mzLRCWalksFunc, (ClientData) NULL);
 
     /* Paint walks into blockage planes (and dealloc walk list) */
 
@@ -1017,7 +1021,8 @@ mzDestWalksFunc(tile, cxp)
     RouteType *rT;
     int mzHWalksFunc();
     int mzVWalksFunc();
-    int mzCWalksFunc();
+    int mzUDCWalksFunc();
+    int mzLRCWalksFunc();
     TileTypeBitMask destAreaMask;
 
     /* Transform to result coordinates */
@@ -1060,7 +1065,12 @@ mzDestWalksFunc(tile, cxp)
 
     DBSrPaintArea(NULL,	/* no hint tile */
 		      rT->rt_hBlock, &rect, 
-		      &destAreaMask, mzCWalksFunc, 
+		      &destAreaMask, mzLRCWalksFunc, 
+		      (ClientData) rT);
+
+    DBSrPaintArea(NULL,	/* no hint tile */
+		      rT->rt_vBlock, &rect, 
+		      &destAreaMask, mzUDCWalksFunc, 
 		      (ClientData) rT);
 
     /* continue with next dest area */
@@ -1244,20 +1254,20 @@ mzVWalksFunc(tile, cdarg)
 }
 
 /* 
- *  Struc to pass data between mzCWalksFunc and mzCWalksFunc2
+ *  Structure to pass data between mzLRCWalksFunc, mzUDCWalksFunc, and mzCWalksFunc2
  */
 typedef struct walkContactFuncData
 {
     Rect		*wd_bounds;	/* dest area bounds */
     RouteLayer 		*wd_rL;		/* Route layer of walk_contact */
-    int			wd_walk;	/* TT_ABOVE_WALK or TT_BELOW_WALK */
+    int			wd_walk;	/* TT_ABOVE_*_WALK or TT_BELOW_*_WALK */
 } WalkContactFuncData;
 
 
 /*
  * ----------------------------------------------------------------------------
  *
- * mzCWalksFunc --
+ * mzLRCWalksFunc --
  *
  * Search dest area for regions where contacts are ok, and paint
  * CONTACT_WALK(s) there in adjacent layers.
@@ -1272,7 +1282,7 @@ typedef struct walkContactFuncData
  */
 
 int
-mzCWalksFunc(tile, cdarg)
+mzLRCWalksFunc(tile, cdarg)
     Tile *tile;
     ClientData cdarg;
 {
@@ -1296,12 +1306,12 @@ mzCWalksFunc(tile, cdarg)
 	if (&(rC->rc_rLayer1->rl_routeType) == rT)
 	{
 	    rLOther = rC->rc_rLayer2;
-	    walkType = TT_ABOVE_WALK;
+	    walkType = TT_ABOVE_LR_WALK;
 	}
 	else if (&(rC->rc_rLayer2->rl_routeType) == rT)
 	{
 	    rLOther = rC->rc_rLayer1;
-	    walkType = TT_BELOW_WALK;
+	    walkType = TT_BELOW_LR_WALK;
 	}
 
 	/* If current contact type (RC) permits connection to dest area, 
@@ -1321,7 +1331,9 @@ mzCWalksFunc(tile, cdarg)
 	    wD.wd_rL = rLOther;
 	    wD.wd_walk = walkType;
 
-	    /* search for OK places for contact, and paint them */
+	    /* search for OK places for contact in the horizontal plane	*/
+	    /* and paint them.						*/
+
 	    DBSrPaintArea(NULL,	/* no hint tile */
 			      rC->rc_routeType.rt_hBlock,
 			      &rect, 
@@ -1335,6 +1347,89 @@ mzCWalksFunc(tile, cdarg)
     return(0);
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * mzUDCWalksFunc --
+ *
+ * Search dest area for regions where contacts are ok, and paint
+ * CONTACT_WALK(s) there in adjacent layers.
+ *
+ * Results:
+ *	Returns 0 always.
+ *
+ * Side effects:
+ *	Paints into adjacent blocakge planes.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+int
+mzUDCWalksFunc(tile, cdarg)
+    Tile *tile;
+    ClientData cdarg;
+{
+    RouteType *rT = (RouteType *) cdarg; /* RouteType of this dest area */
+    RouteContact *rC;	
+    Rect rect;
+    int walkType;
+
+    /* set rect to boundary of this dest area */
+    TITORECT(tile, &rect);
+
+    /* process contact types that can connect to this dest area */
+    for (rC = mzRouteContacts; rC != NULL; rC = rC->rc_next)
+    {
+	RouteLayer *rLOther = NULL; 
+
+	/* skip inactive contact types */
+	if (!(rC->rc_routeType.rt_active)) continue;
+
+	/* Find layer connecting to dest area FROM */
+	if (&(rC->rc_rLayer1->rl_routeType) == rT)
+	{
+	    rLOther = rC->rc_rLayer2;
+	    walkType = TT_ABOVE_UD_WALK;
+	}
+	else if (&(rC->rc_rLayer2->rl_routeType) == rT)
+	{
+	    rLOther = rC->rc_rLayer1;
+	    walkType = TT_BELOW_UD_WALK;
+	}
+
+	/* If current contact type (RC) permits connection to dest area, 
+	 * insert CONTACT_WALK(s) into blockage planes for other layer.
+	 */
+	if (rLOther)
+	{
+	    /* process contact-OK tiles in blockage plane for this contact */
+	    int mzCWalksFunc2();
+	    WalkContactFuncData wD;
+	    TileTypeBitMask contactOKMask;
+
+	    TTMaskSetOnlyType(&contactOKMask, TT_SPACE);
+	    TTMaskSetType(&contactOKMask, TT_SAMENODE);
+
+	    wD.wd_bounds = &rect; 
+	    wD.wd_rL = rLOther;
+	    wD.wd_walk = walkType;
+
+	    /* search for OK places for contact in the vertical plane	*/
+	    /* and paint them.						*/
+
+	    DBSrPaintArea(NULL,	/* no hint tile */
+			      rC->rc_routeType.rt_vBlock,
+			      &rect, 
+			      &contactOKMask,
+			      mzCWalksFunc2, 
+			      (ClientData) &wD);
+	}
+    }
+    
+    /* return 0 - to continue search */
+    return(0);
+}
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -1367,6 +1462,8 @@ mzCWalksFunc2(tile, cdarg)
     TITORECT(tile, &rect);
     GEOCLIP(&rect, wD->wd_bounds);
 
+    /* To-do: check if non-square contacts fit? */
+
     /* Build walks for contacts above or below the tile */
     {
 	walk = (Walk *) mallocMagic((unsigned) (sizeof(Walk)));
