@@ -20,7 +20,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/netmenu/NMwiring.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/netmenu/NMwiring.c,v 1.3 2008/12/11 04:20:11 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -181,7 +181,7 @@ NMRipup()
     {
 	DBErase(EditCellUse->cu_def, &list->nmwa_area, list->nmwa_type);
 	TTMaskSetType(&maskBits, list->nmwa_type);
-	(void) DBEraseLabel(EditCellUse->cu_def, &list->nmwa_area, &maskBits);
+	(void) DBEraseLabel(EditCellUse->cu_def, &list->nmwa_area, &maskBits, NULL);
 	TTMaskClearType(&maskBits, list->nmwa_type);
 	DRCCheckThis(EditCellUse->cu_def, TT_CHECKPAINT, &list->nmwa_area);
 	DBWAreaChanged(EditCellUse->cu_def, &list->nmwa_area, DBW_ALLWINDOWS,
@@ -240,7 +240,7 @@ nmRipLocFunc(rect, name, label, area)
     {
 	DBErase(EditCellUse->cu_def, &list->nmwa_area, list->nmwa_type);
 	TTMaskSetType(&maskBits, list->nmwa_type);
-	(void) DBEraseLabel(EditCellUse->cu_def, &list->nmwa_area, &maskBits);
+	(void) DBEraseLabel(EditCellUse->cu_def, &list->nmwa_area, &maskBits, NULL);
 	TTMaskClearType(&maskBits, list->nmwa_type);
 	(void) GeoInclude(&list->nmwa_area, area);
 	freeMagic((char *) list);
@@ -495,7 +495,7 @@ nmwNetTileFunc(tile, plane, netPtr)
     tpath.tp_last = &label[TERMLENGTH-1];
     nmwGotTerm = FALSE;
     if (DBTreeSrLabels(&scx, &DBConnectTbl[TiGetType(tile)], 0, &tpath,
-	nmwNetTermFunc, (ClientData) netPtr) != 0)
+	TF_LABEL_ATTACH, nmwNetTermFunc, (ClientData) netPtr) != 0)
     {
 	/* Non-zero return value means no current netlist.  Quit now. */
 	return 1;
@@ -727,7 +727,7 @@ nmwVerifyTileFunc(tile, plane, func)
     tpath.tp_next = label;
     tpath.tp_last = &label[TERMLENGTH-1];
     (void) DBTreeSrLabels(&scx, &DBConnectTbl[TiGetType(tile)],
-	0, &tpath, nmwVerifyLabelFunc2, (ClientData) func);
+	0, &tpath, TF_LABEL_ATTACH, nmwVerifyLabelFunc2, (ClientData) func);
     return 0;
 }
 
