@@ -16,7 +16,7 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid $Header: /usr/cvsroot/magic-8.0/plot/plotInt.h,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $
+ * rcsid $Header: /usr/cvsroot/magic-8.0/plot/plotInt.h,v 1.2 2010/03/08 13:33:33 tim Exp $
  */
 
 #ifndef _PLOTINT_H
@@ -28,7 +28,7 @@
 #define VERSATEC		/* Add this for HP plotter support */
 
 /* system V machines lack vfont.h, so include the defs below. */
-#if  !defined(SYSV) && !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(CYGWIN) && !defined(macosx)
+#if  !defined(SYSV) && !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(CYGWIN) && !defined(macosx) && !defined(__DragonFly__)
 #include <vfont.h>
 #else
 struct header {
