@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/plot/plotPS.c,v 1.2 2008/06/01 18:37:45 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/plot/plotPS.c,v 1.3 2010/06/24 12:37:25 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -533,7 +533,6 @@ plotPSPaint(tile, cxp)
 	return 0;
     }
 
-#ifdef NONMANHATTAN
     /* If this is a triangle, output the last rect and deal with this one */
     /* individually.							  */
 
@@ -587,49 +586,45 @@ plotPSPaint(tile, cxp)
     }
     else
     {
-#endif
 
-    /* This tile gets "normal" processing (i.e. stippling and outlining).
-     * Clip it to the plotting area and output.
-     */
+	/* This tile gets "normal" processing (i.e. stippling and outlining).
+	 * Clip it to the plotting area and output.
+	 */
 
-    GeoClip(&rootArea, &bbox);
-    xbot = rootArea.r_xbot - bbox.r_xbot;
-    width = rootArea.r_xtop - rootArea.r_xbot;
-    ybot = rootArea.r_ybot - bbox.r_ybot;
-    height = rootArea.r_ytop - rootArea.r_ybot;
+	GeoClip(&rootArea, &bbox);
+	xbot = rootArea.r_xbot - bbox.r_xbot;
+	width = rootArea.r_xtop - rootArea.r_xbot;
+	ybot = rootArea.r_ybot - bbox.r_ybot;
+	height = rootArea.r_ytop - rootArea.r_ybot;
 
-    /* compare against last output rectangle and merge if possible */
-    if ((width == curwidth) && (xbot == curxbot) && ((tmptf = (ybot == curybot
-	+ curheight)) || (ybot + height == curybot)))
-    {
-	curheight += height;
-	if (!tmptf) curybot = ybot; 
-    }
-    else if ((height == curheight) && (ybot == curybot) && ((tmptf = (xbot == curxbot
-	+ curwidth)) || (xbot + width == curxbot)))
-    {
-	curwidth += width;
-	if (!tmptf) curxbot = xbot;
-    }
-    else
-    {
-	plotPSFlushRect(curStyle->grs_stipple);
-	curheight = height;
-	curwidth = width;
-	curxbot = xbot;
-	curybot = ybot;
-    }
+	/* compare against last output rectangle and merge if possible */
+	if ((width == curwidth) && (xbot == curxbot) && ((tmptf = (ybot == curybot
+			+ curheight)) || (ybot + height == curybot)))
+	{
+	    curheight += height;
+	    if (!tmptf) curybot = ybot; 
+	}
+	else if ((height == curheight) && (ybot == curybot) && ((tmptf = (xbot	
+		== curxbot + curwidth)) || (xbot + width == curxbot)))
+	{
+	    curwidth += width;
+	    if (!tmptf) curxbot = xbot;
+	}
+	else
+	{
+	    plotPSFlushRect(curStyle->grs_stipple);
+	    curheight = height;
+	    curwidth = width;
+	    curxbot = xbot;
+	    curybot = ybot;
+	}
 
-    if (PlotPSBoundary && (curLineWidth != PS_THIN)) {
-	fprintf(file, "l1\n");
-	curLineWidth = PS_THIN;
+	if (PlotPSBoundary && (curLineWidth != PS_THIN)) {
+	    fprintf(file, "l1\n");
+	    curLineWidth = PS_THIN;
+	}
     }
 
-#ifdef NONMANHATTAN
-    }
-#endif
-
     if (!PlotPSBoundary) return 0;	/* No borders */
 
     /* Now output lines for any edges between material of the type
@@ -641,10 +636,8 @@ plotPSPaint(tile, cxp)
      * (This code is essentially a duplicate of selRedisplayFunc())
      */
     
-#ifdef NONMANHATTAN
     if (IsSplit(tile) && (!(SplitSide(tile) ^ SplitDirection(tile))))
         goto searchleft;        /* nothing on bottom of split */
-#endif
 
     if (tileArea.r_ybot > TiPlaneRect.r_ybot)
     {
@@ -652,11 +645,7 @@ plotPSPaint(tile, cxp)
 	for (neighbor = LB(tile); LEFT(neighbor) < tileArea.r_xtop;
 		neighbor = TR(neighbor))
 	{
-#ifdef NONMANHATTAN
 	    ntype = TiGetTopType(neighbor);
-#else
-	    ntype = TiGetTypeExact(neighbor);
-#endif
 	    if (TTMaskHasType(&curMask, ntype)) continue;
 	    edge.r_xbot = LEFT(neighbor);
 	    edge.r_xtop = RIGHT(neighbor);
@@ -672,10 +661,8 @@ plotPSPaint(tile, cxp)
      */
 
 searchleft:
-#ifdef NONMANHATTAN
     if (IsSplit(tile) && SplitSide(tile))
 	goto searchtop;		/* Nothing on left side of tile */
-#endif
 
     if (tileArea.r_xbot > TiPlaneRect.r_xbot)
     {
@@ -683,11 +670,7 @@ searchleft:
 	for (neighbor = BL(tile); BOTTOM(neighbor) < tileArea.r_ytop;
 		neighbor = RT(neighbor))
 	{
-#ifdef NONMANHATTAN
  	    ntype = TiGetRightType(neighbor);
-#else
-	    ntype = TiGetTypeExact(neighbor);
-#endif
 	    if (TTMaskHasType(&curMask, ntype)) continue;
 	    edge.r_ybot = BOTTOM(neighbor);
 	    edge.r_ytop = TOP(neighbor);
@@ -701,10 +684,8 @@ searchleft:
     /* Same thing for the tile's top border. */
 
 searchtop:
-#ifdef NONMANHATTAN
     if (IsSplit(tile) && (SplitSide(tile) ^ SplitDirection(tile)))
 	goto searchright;		/* Nothing on top side of tile */
-#endif
 
     if (tileArea.r_ytop < TiPlaneRect.r_ytop)
     {
@@ -712,11 +693,7 @@ searchtop:
 	for (neighbor = RT(tile); RIGHT(neighbor) > tileArea.r_xbot;
 		neighbor = BL(neighbor))
 	{
-#ifdef NONMANHATTAN
 	    ntype = TiGetBottomType(neighbor);
-#else
-	    ntype = TiGetTypeExact(neighbor);
-#endif
 	    if (TTMaskHasType(&curMask, ntype)) continue;
 	    edge.r_xbot = LEFT(neighbor);
 	    edge.r_xtop = RIGHT(neighbor);
@@ -730,10 +707,8 @@ searchtop:
     /* Finally, the right border. */
 
 searchright:
-#ifdef NONMANHATTAN
     if (IsSplit(tile) && !SplitSide(tile))
 	return 0;		/* Nothing on right side of tile */
-#endif
 
     if (tileArea.r_xtop < TiPlaneRect.r_xtop)
     {
@@ -741,11 +716,7 @@ searchright:
 	for (neighbor = TR(tile); TOP(neighbor) > tileArea.r_ybot;
 		neighbor = LB(neighbor))
 	{
-#ifdef NONMANHATTAN
 	    ntype = TiGetLeftType(neighbor);
-#else
-	    ntype = TiGetTypeExact(neighbor);
-#endif
 	    if (TTMaskHasType(&curMask, ntype)) continue;
 	    edge.r_ybot = BOTTOM(neighbor);
 	    edge.r_ytop = TOP(neighbor);
