@@ -4,7 +4,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/resis/ResConDCS.c,v 1.4 2009/01/30 03:11:15 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/resis/ResConDCS.c,v 1.5 2010/06/24 12:37:56 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -33,9 +33,7 @@ typedef struct
 {
     Rect		area;		/* Area to process */
     TileTypeBitMask	*connectMask;	/* Connection mask for search */
-#ifdef NONMANHATTAN
     TileType		dinfo;		/* Info about triangular search areas */
-#endif
 } conSrArea;
 
 struct conSrArg2
@@ -94,9 +92,7 @@ dbcConnectFuncDCS(tile, cx)
     TileTypeBitMask	notConnectMask, *connectMask;
     Tile		*tp;
     TileType		t2, t1, loctype, ctype;
-#ifdef NONMANHATTAN
     TileType		dinfo = 0;
-#endif
     SearchContext	*scx = cx->tc_scx;
     int			pNum;
     CellDef		*def;
@@ -219,7 +215,6 @@ dbcConnectFuncDCS(tile, cx)
 
     loctype = TiGetTypeExact(tile);
 
-#ifdef NONMANHATTAN
     /* Resolve geometric transformations on diagonally-split tiles */
 
     if (IsSplit(tile))
@@ -227,7 +222,6 @@ dbcConnectFuncDCS(tile, cx)
 	dinfo = DBTransformDiagonal(loctype, &scx->scx_trans);
 	loctype = (SplitSide(tile)) ? SplitRightType(tile) : SplitLeftType(tile);
     }
-#endif
 
     pNum = DBPlane(loctype);
     connectMask = &csa2->csa2_connect[loctype];
@@ -263,28 +257,15 @@ dbcConnectFuncDCS(tile, cx)
 
     def = csa2->csa2_use->cu_def;
 
-#ifdef NONMANHATTAN
     if (DBSrPaintNMArea((Tile *) NULL, def->cd_planes[pNum],
 		dinfo, &newarea, &notConnectMask, dbcUnconnectFunc,
 		(ClientData) connectMask) == 0)
 	return 0;
-#else
-    if (DBSrPaintArea((Tile *) NULL, def->cd_planes[pNum],
-	    &newarea, &notConnectMask, dbcUnconnectFunc,
-	    (ClientData) connectMask) == 0)
-	return 0;
-#endif
 
-#ifdef NONMANHATTAN
     DBNMPaintPlane(def->cd_planes[pNum], dinfo,
 		&newarea, DBStdPaintTbl(loctype, pNum),
 		(PaintUndoInfo *) NULL);
-#else
-    DBPaintPlane(def->cd_planes[pNum], &newarea,
-	    DBStdPaintTbl(loctype, pNum), (PaintUndoInfo *) NULL);
-#endif
 
-#ifdef NONMANHATTAN
     /* Only extend those sides bordering the diagonal tile */
 
     if (dinfo & TT_DIAGONAL)
@@ -301,14 +282,11 @@ dbcConnectFuncDCS(tile, cx)
     }
     else
     {
-#endif
-    newarea.r_xbot -= 1;
-    newarea.r_ybot -= 1;
-    newarea.r_xtop += 1;
-    newarea.r_ytop += 1;
-#ifdef NONMANHATTAN
+	newarea.r_xbot -= 1;
+	newarea.r_ybot -= 1;
+	newarea.r_xtop += 1;
+	newarea.r_ytop += 1;
     }
-#endif
 
     /* Register the area and connection mask as needing to be processed */
 
@@ -327,9 +305,7 @@ dbcConnectFuncDCS(tile, cx)
 	{
 	    newlist[i].area = csa2->csa2_list[i].area;
 	    newlist[i].connectMask = csa2->csa2_list[i].connectMask;
-#ifdef NONMANHATTAN
 	    newlist[i].dinfo = csa2->csa2_list[i].dinfo;
-#endif
 	}
 	freeMagic((char *)csa2->csa2_list);
 	csa2->csa2_list = newlist;
@@ -337,9 +313,7 @@ dbcConnectFuncDCS(tile, cx)
 
     csa2->csa2_list[csa2->csa2_top].area = newarea;
     csa2->csa2_list[csa2->csa2_top].connectMask = connectMask;
-#ifdef NONMANHATTAN
     csa2->csa2_list[csa2->csa2_top].dinfo = dinfo;
-#endif
 
     return 0;
 }
@@ -450,9 +424,7 @@ DBTreeCopyConnectDCS(scx, mask, xMask, connect, area, destUse)
     TileTypeBitMask	*newmask;
     ResTranTile		*CurrentT;
     CellDef		*def = destUse->cu_def;
-#ifdef NONMANHATTAN
     TileType		newtype;
-#endif
 
     csa2.csa2_use = destUse;
     csa2.csa2_bounds = area;
@@ -487,17 +459,13 @@ DBTreeCopyConnectDCS(scx, mask, xMask, connect, area, destUse)
     {
 	newmask = csa2.csa2_list[csa2.csa2_top].connectMask;
 	scx->scx_area = csa2.csa2_list[csa2.csa2_top].area;
-#ifdef NONMANHATTAN
 	newtype = csa2.csa2_list[csa2.csa2_top].dinfo;
-#endif
 	csa2.csa2_top--;
-#ifdef NONMANHATTAN
 	if (newtype & TT_DIAGONAL)
 	    DBTreeSrNMTiles(scx, newtype, newmask, xMask, dbcConnectFuncDCS,
 			(ClientData) &csa2);
 	else
-#endif
-	DBTreeSrTiles(scx, newmask, xMask, dbcConnectFuncDCS, (ClientData) &csa2);
+	    DBTreeSrTiles(scx, newmask, xMask, dbcConnectFuncDCS, (ClientData) &csa2);
     }
     freeMagic((char *)csa2.csa2_list);
 
