@@ -1,6 +1,6 @@
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/resis/ResPrint.c,v 1.2 2006/11/10 18:17:53 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/resis/ResPrint.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -8,6 +8,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/
 #include <ctype.h>
 #include <math.h>
 
+#include "tcltk/tclmagic.h"
 #include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -107,29 +108,45 @@ ResPrintExtRes(outextfile,resistors,nodename)
  */
 
 void
-ResPrintExtTran(outextfile,transistors)
-	FILE		*outextfile;
-	RTran		*transistors;
-
+ResPrintExtTran(outextfile, transistors)
+    FILE	*outextfile;
+    RTran	*transistors;
 {
-     for (; transistors != NULL; transistors=transistors->nextTran)
-     {
-     	  if (transistors->status & TRUE)
-	  {
-	       if (ResOptionsFlags & ResOpt_DoExtFile)
-	       {
-	       /*  fet type xl yl xh yh area perim sub gate t1 t2 */
-	            fprintf(outextfile,"fet %s %d %d %d %d %d %d %s \"%s\" %d %s \"%s\" %d %s \"%s\" %d %s\n",
-	       		ExtCurStyle->exts_transName[transistors->layout->rt_trantype],
-	       		transistors->layout->rt_inside.r_ll.p_x,
-		        transistors->layout->rt_inside.r_ll.p_y,
-	       		transistors->layout->rt_inside.r_ll.p_x+1,
-		        transistors->layout->rt_inside.r_ll.p_y+1,
+    TileType t;
+    char *subsName;
+
+    for (; transistors != NULL; transistors = transistors->nextTran)
+    {
+	if (transistors->status & TRUE)
+	{
+	    if (ResOptionsFlags & ResOpt_DoExtFile)
+	    {
+		t = transistors->layout->rt_trantype;
+		subsName = ExtCurStyle->exts_transSubstrateName[t];
+
+#ifdef MAGIC_WRAPPER
+		/* Substrate variable name substitution */
+		if (subsName && subsName[0] == '$' && subsName[1] != '$')
+		{
+		    char *varsub = (char *)Tcl_GetVar(magicinterp, &subsName[1],
+				TCL_GLOBAL_ONLY);
+		    if (varsub != NULL) subsName = varsub;
+		}
+#endif
+
+		/* fet type xl yl xh yh area perim sub gate t1 t2 */
+		fprintf(outextfile,"fet %s %d %d %d %d %d %d "
+				"%s \"%s\" %d %s \"%s\" %d %s \"%s\" %d %s\n",
+			ExtCurStyle->exts_transName[t],
+			transistors->layout->rt_inside.r_ll.p_x,
+			transistors->layout->rt_inside.r_ll.p_y,
+			transistors->layout->rt_inside.r_ll.p_x + 1,
+			transistors->layout->rt_inside.r_ll.p_y + 1,
 			transistors->layout->rt_area,
 			transistors->layout->rt_perim,
-	       		ExtCurStyle->exts_transSubstrateName[transistors->layout->rt_trantype],
+			subsName,
 			transistors->gate->name,
-			transistors->layout->rt_length*2,
+			transistors->layout->rt_length * 2,
 			transistors->rs_gattr,
 			transistors->source->name,
 			transistors->layout->rt_width,
@@ -137,9 +154,9 @@ ResPrintExtTran(outextfile,transistors)
 			transistors->drain->name,
 			transistors->layout->rt_width,
 			transistors->rs_dattr);
-		}
-	  }
-     }
+	    }
+	}
+    }
 }
 
 
