@@ -20,7 +20,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/select/selEnum.c,v 1.12 2010/05/18 14:21:13 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/select/selEnum.c,v 1.13 2010/06/24 12:37:56 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -194,7 +194,6 @@ selEnumPFunc1(tile, arg)
 
     TiToRect(tile, &arg->sea_rect);
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
 	arg->sea_type = TiGetTypeExact(tile) & (TT_DIAGONAL | TT_SIDE | TT_DIRECTION);
@@ -204,14 +203,11 @@ selEnumPFunc1(tile, arg)
 	    loctype = SplitLeftType(tile);
     }
     else 
-#endif
-    loctype = TiGetType(tile);
+	loctype = TiGetType(tile);
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
 	arg->sea_type |= loctype;
     else
-#endif
 	arg->sea_type = loctype;
 
     /* If the paint doesn't have to be in the edit cell, life's pretty
@@ -244,14 +240,12 @@ selEnumPFunc1(tile, arg)
     if (!TTMaskIsZero(&SelectDef->cd_types))
 	arg->sea_flags |= SEA_AREA;
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
 	DBSrPaintNMArea((Tile *)NULL,
 		EditCellUse->cu_def->cd_planes[arg->sea_plane],
 		arg->sea_type, &editRect, &DBAllTypeBits, selEnumPFunc2,
 		(ClientData)arg);
     else
-#endif
 	DBSrPaintArea((Tile *)NULL,
 		EditCellUse->cu_def->cd_planes[arg->sea_plane],
 		&editRect, &DBAllTypeBits, selEnumPFunc2,
@@ -288,18 +282,12 @@ selEnumPFunc2(tile, arg)
     int ttype;
     TileType seltype;
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
 	ttype = SplitSide(tile) ? SplitRightType(tile) : SplitLeftType(tile);
     else
 	ttype = TiGetTypeExact(tile);
     seltype = arg->sea_type & TT_LEFTMASK;
 
-#else
-    ttype = TiGetType(tile);
-    seltype = arg->sea_type;
-#endif
-
     /* Handle stacked contact types */
     if ((ttype != seltype) && (ttype >= DBNumUserLayers))
     {
@@ -380,7 +368,6 @@ selEnumPFunc2(tile, arg)
     lr = (ExtRectList *)mallocMagic(sizeof(ExtRectList));
     TiToRect(tile, &lr->r_r);
 
-#ifdef NONMANHATTAN
     if (arg->sea_type & TT_DIAGONAL)
     {
 	Point points[5];
@@ -503,9 +490,6 @@ topbottom:
     }
     else
 	lr->r_type = ttype;
-#else
-    lr->r_type = ttype;
-#endif
 
 splitdone:
     lr->r_next = arg->sea_rectList;
