@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/select/selOps.c,v 1.9 2008/12/11 04:20:13 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/select/selOps.c,v 1.11 2010/08/22 21:58:26 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -144,8 +144,6 @@ selDelPaintFunc(rect, type)
     TileTypeBitMask tmask;
     TileType dinfo;
 
-#ifdef NONMANHATTAN
-
     /* Change diagonal side & direction according to the transform */
 
     if (type & TT_DIAGONAL)
@@ -154,7 +152,6 @@ selDelPaintFunc(rect, type)
 	TTMaskSetOnlyType(&tmask, type & TT_LEFTMASK);   
     }
     else
-#endif
     {
 	dinfo = 0;
 	TTMaskSetOnlyType(&tmask, type);   
@@ -359,8 +356,6 @@ selTransPaintFunc(rect, type, transform)
     Rect newarea;
     TileType loctype;
 
-#ifdef NONMANHATTAN
-
     /* Change diagonal direction according to the transform */
     if (type & TT_DIAGONAL)
     {
@@ -369,7 +364,6 @@ selTransPaintFunc(rect, type, transform)
 		(type & TT_LEFTMASK);
     }
     else
-#endif
 	loctype = type;
 
     GeoTransRect(transform, rect, &newarea);
@@ -716,7 +710,10 @@ selArrayLFunc(label, use, transform, arrayInfo)
     int y, nx, ny, rootJust, rootRotate;
     Point rootOffset;
     Rect original, current;
-    int labx, laby, xi, yi, only1;		/* numeric parts of label */
+    char *astr;
+    int labx, laby, xi, yi, only1;	/* numeric parts of label */
+
+    char *nmPutNums();			/* Forward reference */
 
     nx = arrayInfo->ar_xhi - arrayInfo->ar_xlo;
     if (nx < 0) nx = -nx;
@@ -749,13 +746,11 @@ selArrayLFunc(label, use, transform, arrayInfo)
 	     * the same text and position is considered a duplicate.
 	     */
 	    yi = ny - y;
-	    DBEraseLabelsByContent(Select2Def, &current, -1,
-			nmPutNums(label->lab_text, labx + xi, laby +yi));
+	    astr = nmPutNums(label->lab_text, labx + xi, laby + yi);
+	    DBEraseLabelsByContent(Select2Def, &current, -1, astr);
 	    DBPutFontLabel(Select2Def, &current, label->lab_font,
 			label->lab_size, rootRotate, &rootOffset,
-			rootJust,
-			nmPutNums(label->lab_text, labx + xi, laby + yi),
-		label->lab_type, label->lab_flags);
+			rootJust, astr, label->lab_type, label->lab_flags);
 	    current.r_ybot += arrayInfo->ar_ysep;
 	    current.r_ytop += arrayInfo->ar_ysep;
 	    xi += only1;
@@ -854,14 +849,10 @@ SelectStretch(x, y)
 	TileTypeBitMask tmask;
 	TileType type = selStretchList->sa_type;
 
-#ifdef NONMANHATTAN
 	TileType tloc;
 	tloc = (type & TT_DIAGONAL) ?  ((type & TT_SIDE) ?
 		(type & TT_RIGHTMASK) >> 14 : (type & TT_LEFTMASK)) : type;
 	TTMaskSetOnlyType(&tmask, tloc);
-#else
-	TTMaskSetOnlyType(&tmask, type);
-#endif
 
 	DBPaintValid(EditCellUse->cu_def, &selStretchList->sa_area, &tmask, type);
 	freeMagic((char *) selStretchList);
@@ -909,13 +900,11 @@ selStretchEraseFunc(tile, plane)
     PaintResultType selStretchEraseTbl[NT];
     extern int selStretchEraseFunc2();
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
 	type = (SplitSide(tile)) ? SplitRightType(tile) :
 			SplitLeftType(tile);
     else
-#endif
-    type = TiGetType(tile);
+	type = TiGetType(tile);
 
     TiToRect(tile, &area);
 
@@ -1027,7 +1016,6 @@ selStretchEraseFunc2(tile, pa)
     Tile *tile;
     planeAndArea *pa;
 {
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
 	if (TTMaskHasType(pa->pa_mask, TiGetLeftType(tile)))
@@ -1038,7 +1026,6 @@ selStretchEraseFunc2(tile, pa)
 			DBPlaneToResidue(TiGetRightType(tile), pa->pa_plane));
     }
     else
-#endif
 	DBErase(EditCellUse->cu_def, pa->pa_area,
 		DBPlaneToResidue(TiGetType(tile), pa->pa_plane));
     return 0;
@@ -1099,7 +1086,6 @@ selStretchFillFunc(tile, plane)
 	area.r_ytop += 1;
     }
 
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
 	if (selStretchX > 0)
@@ -1115,8 +1101,7 @@ selStretchFillFunc(tile, plane)
 	if (selStretchType == TT_SPACE) return 0;
     }
     else
-#endif
-    selStretchType = TiGetType(tile);
+	selStretchType = TiGetType(tile);
 
     /* The search functions invoked indirectly by the following procedure
      * call build up a list of areas to paint.
@@ -1226,7 +1211,6 @@ selStretchFillFunc3(tile, area)
      * must use the master image.
      */
     
-#ifdef NONMANHATTAN
     if (IsSplit(tile))
     {
 	if (selStretchX > 0)
@@ -1242,8 +1226,7 @@ selStretchFillFunc3(tile, area)
 	if (type == TT_SPACE) return 0;   /* nothing to stretch */
     }
     else
-#endif
-    type = TiGetType(tile);
+	type = TiGetType(tile);
     sMask = DBResidueMask(selStretchType);
 
     /* If have type and stretch type are both contacts (fixed types)	*/
