@@ -32,12 +32,12 @@ done
 if [ $TKCON ]; then
 
    if [ $DNULL ]; then
-      exec /home/tim/cad/lib/magic/tcl/tkcon.tcl -eval "source /home/tim/cad/lib/magic/tcl/console.tcl" \
-	   -slave "set argc $#; set argv [list $*]; source /home/tim/cad/lib/magic/tcl/magic.tcl"
+      exec /home/tim/cad//lib/magic/tcl/tkcon.tcl -eval "source /home/tim/cad//lib/magic/tcl/console.tcl" \
+	   -slave "set argc $#; set argv [list $*]; source /home/tim/cad//lib/magic/tcl/magic.tcl"
    else
-      exec /home/tim/cad/lib/magic/tcl/tkcon.tcl -eval "source /home/tim/cad/lib/magic/tcl/console.tcl" \
+      exec /home/tim/cad//lib/magic/tcl/tkcon.tcl -eval "source /home/tim/cad//lib/magic/tcl/console.tcl" \
 	   -slave "package require Tk; set argc $#; set argv [list $*]; \
-	   source /home/tim/cad/lib/magic/tcl/magic.tcl"
+	   source /home/tim/cad//lib/magic/tcl/magic.tcl"
    fi
 
 else
@@ -52,8 +52,8 @@ else
 # only, efficient for running in batch mode).
 #
    if [ $DNULL ]; then
-      exec /home/tim/cad/lib/magic/tcl/magicdnull -nowrapper $@
+      exec /home/tim/cad//lib/magic/tcl/magicdnull -nowrapper $@
    else
-      exec /home/tim/cad/lib/magic/tcl/magicexec -- $@
+      exec /home/tim/cad//lib/magic/tcl/magicexec -- $@
    fi
 fi
