@@ -87,27 +87,47 @@ proc magic::pushstack {{name ""}} {
 	 popbox
       }
       set name [cellname list self]
-      if {$name == ""} {
-	 error "No cell to push!"
-      } elseif {[llength $name] > 1} {
-         error "Too many cells selected!"
-      }
+   }
+
+   if {$name == ""} {
+       error "No cell to push!"
+   } elseif {[llength $name] > 1} {
+       error "Too many cells selected!"
    }
    if {[catch {lindex $editstack end}]} {
       set editstack {}
    }
    lappend editstack [cellname list window]
+   set ltag [tag load]
+   tag load {}
    load $name
+   catch {magic::cellmanager}
+   magic::captions
+   tag load $ltag
    return
 }
 
 proc magic::popstack {} {
    global editstack
-   load [lindex $editstack end]             
-   set editstack [lrange $editstack 0 end-1]
+   if {[llength $editstack] == 0} {
+      error "No subcell stack!"
+   } else {
+      set ltag [tag load]
+      tag load {}
+      load [lindex $editstack end]             
+      tag load $ltag
+      set editstack [lrange $editstack 0 end-1]
+      catch {magic::cellmanager}
+      magic::captions
+   }
    return
 }
 
+proc magic::clearstack {} {
+   global editstack
+   set editstack {}
+}
+
 # More stacking stuff---stacked box values
 
 #---------------------------------------------------------------------
