@@ -9,15 +9,13 @@
 # revision C: Adds a layer manager toolbar on the left side
 # revision D: Adds a menubar on top with cell and tech manager tools
 
-global MagicBLT
 global windowsopen
+global tk_version
 global Glyph
 global Opts
 global Winopts
 
-set MagicBLT 0
-if {! [catch {package require BLT}]} {set MagicBLT 1}
-
+set tk_version $::tk_version
 # Simple console commands (like TkCon, but much simpler)
 
 if {[lsearch [namespace children] ::tkshell] < 0} {
@@ -152,69 +150,6 @@ proc magic::promptsave {type} {
    }
 }
 
-# Callback to the cell manager
-
-proc magic::instcallback {command} {
-   global Opts
-
-   set rpath [join [.cellmgr.box.view get -full anchor]]
-   set rootdef [lindex $rpath 0]
-   set cellpath [lrange $rpath 1 end]
-
-   if { $Opts(target) == "default" } {
-      set winlist [magic::windownames layout]
-      set winname [lindex $winlist 0]
-   } else {
-      set winname $Opts(target)
-   }
-
-   if { $cellpath == {} } {
-      switch $command {
-	 load {$winname load $rootdef}
-	 default {
-	    magic::select top cell
-	    switch $command {
-	       edit {$winname expand; $winname edit}
-	       expand {$winname expand}
-	       zoom {$winname view}
-	    }
-	 }
-      }
-   } else {
-      set celluse [join $cellpath "/"]
-      set celldef [magic::instance list celldef $celluse]
-
-      set curpath [$winname windowcaption]
-      set curname [lindex $curpath 2]
-      set curroot [lindex $curpath 0]
-
-      switch $command {
-         load {$winname load $celldef}
-         default {
-	    # Here: need to check first for the select cell belonging to the
-	    # current loaded root cell (get the first use).
-	    set defpath [list $rootdef]
-	    foreach i $cellpath {
-	       lappend defpath [magic::instance list celldef $i]
-	    }
-	    set rootpos [lsearch $defpath $curroot]
-	    if {$rootpos < 0} {
-	       $winname load $rootdef
-	       set rootpos 0
-	    }
-	    set usepath [join [lrange $cellpath $rootpos end] "/"]
-	    $winname select cell ${usepath}
-
-	    switch $command {
-	       edit {$winname expand; $winname edit}
-	       expand {$winname expand toggle}
-	       zoom {$winname findbox zoom}
-	    }
-	 }
-      }
-   }
-}
-
 # Callback functions used by the DRC.
 
 proc magic::drcupdate { option } {
@@ -250,50 +185,6 @@ proc magic::drcstate { status } {
 # and linked into it by the "clone" command.
 
 menu .winmenu -tearoff 0
-# The cell manager
-
-proc magic::makecellmanager { mgrpath } {
-   global MagicBLT
-
-   if {$MagicBLT} {
-      toplevel ${mgrpath}
-      wm withdraw ${mgrpath}
-      frame ${mgrpath}.actionbar
-      frame ${mgrpath}.box
-      frame ${mgrpath}.target
-      blt::hiertable ${mgrpath}.box.view -bg white -allowduplicates false -hideroot true \
-	   -yscrollcommand "${mgrpath}.box.vert set" \
-	   -xscrollcommand "${mgrpath}.box.vert set"
-      scrollbar ${mgrpath}.box.vert -orient vertical -command "${mgrpath}.box.view yview"
-
-      pack ${mgrpath}.actionbar -side top -fill x
-      pack ${mgrpath}.box.view -side left -fill both -expand true
-      pack ${mgrpath}.box.vert -side right -fill y
-      pack ${mgrpath}.box -side top -fill both -expand true
-      pack ${mgrpath}.target -side top -fill x
-
-      button ${mgrpath}.actionbar.done -text "Zoom" -command {magic::instcallback zoom}
-      button ${mgrpath}.actionbar.edit -text "Edit" -command {magic::instcallback edit}
-      button ${mgrpath}.actionbar.load -text "Load" -command {magic::instcallback load}
-      button ${mgrpath}.actionbar.expand -text "Expand" -command \
-		{magic::instcallback expand}
-
-      pack ${mgrpath}.actionbar.load -side left
-      pack ${mgrpath}.actionbar.edit -side left
-      pack ${mgrpath}.actionbar.expand -side left
-      pack ${mgrpath}.actionbar.done -side right
-
-      label ${mgrpath}.target.name -text "Target window:"
-      menubutton ${mgrpath}.target.list -text "default" \
-		-menu ${mgrpath}.target.list.winmenu
- 
-      pack ${mgrpath}.target.name -side left -padx 2
-      pack ${mgrpath}.target.list -side left
-
-      .winmenu clone ${mgrpath}.target.list.winmenu
-   }
-}
-
 
 proc magic::setgrid {gridsize} {
    set techlambda [magic::tech lambda]
@@ -306,184 +197,6 @@ proc magic::setgrid {gridsize} {
    magic::snap on
 }
 
-proc magic::addlistinstance {instin} {
-   set hierinst [join [lrange $instin 1 end] "/"]
-   set defname [magic::instance list celldef $hierinst]
-   set instnum [lindex [split [lindex $instin end] _ ] end]
-   .cellmgr.box.view insert end $instin -label "${defname} (${instnum})"
-
-   set sublist [magic::instance list children $hierinst]
-   foreach i $sublist {
-      set instout [concat $instin $i]
-      magic::addlistinstance $instout
-   }
-}
-
-proc magic::cellmanager {{option "update"}} {
-   global MagicBLT
-   if {$MagicBLT} {
-
-      # Check for existence of the manager widget
-      if {[catch {wm state .cellmgr}]} {
-	 if {$option == "create"} {
-	    magic::makecellmanager .cellmgr
-	 } else {
-	    return
-	 }
-      } elseif { $option == "create"} {
-	 return
-      }
-
-      # determine the full cell heirarchy
-      set tl [magic::cellname list topcells]
-      # remove the previous entry and create a new one
-      .cellmgr.box.view delete all
-      foreach i $tl {
-	 if { [file extension $i] == ".mag" } {
-	    set nameroot [file rootname $i]
-	 } else {
-	    set nameroot $i
-	 }
-	 set nameroot [file tail $nameroot]
-	 .cellmgr.box.view insert end $i -foreground red -label $nameroot
-
-	 set cd [magic::cellname list childinst $i]
-	 foreach j $cd {
-	    set ci [concat $i $j]
-	    magic::addlistinstance $ci
-	 }
-      }
-   }
-}
-
-# Text helper window
-
-proc magic::maketexthelper { mgrpath } {
-   toplevel ${mgrpath}
-   wm withdraw ${mgrpath}
-
-   frame ${mgrpath}.title
-   frame ${mgrpath}.text
-   frame ${mgrpath}.font
-   frame ${mgrpath}.size
-   frame ${mgrpath}.just
-   frame ${mgrpath}.rotate
-   frame ${mgrpath}.offset
-
-   frame ${mgrpath}.buttonbar
-
-   label ${mgrpath}.title.tlab -text "Selected labels: "
-
-   label ${mgrpath}.text.tlab -text "Text string: "
-   label ${mgrpath}.font.tlab -text "Font: "
-   label ${mgrpath}.size.tlab -text "Size: "
-   label ${mgrpath}.just.tlab -text "Justification: "
-   label ${mgrpath}.rotate.tlab -text "Rotation: "
-   label ${mgrpath}.offset.tlab -text "Offset from reference: "
-
-   entry ${mgrpath}.text.tent -background white
-   entry ${mgrpath}.size.tent -background white
-   entry ${mgrpath}.rotate.tent -background white
-   entry ${mgrpath}.offset.tent -background white
-
-   menubutton ${mgrpath}.just.btn -text "default" -menu ${mgrpath}.just.btn.menu
-   menubutton ${mgrpath}.font.btn -text "default" -menu ${mgrpath}.font.btn.menu
-   
-   button ${mgrpath}.buttonbar.cancel -text "Cancel" -command "wm withdraw ${mgrpath}"
-   button ${mgrpath}.buttonbar.apply -text "Apply"
-
-   pack ${mgrpath}.title.tlab
-   pack ${mgrpath}.font.tlab -side left
-   pack ${mgrpath}.font.btn -side left
-   pack ${mgrpath}.text.tlab -side left
-   pack ${mgrpath}.text.tent -side right -fill x -expand true
-   pack ${mgrpath}.size.tlab -side left
-   pack ${mgrpath}.size.tent -side right -fill x -expand true
-   pack ${mgrpath}.just.tlab -side left
-   pack ${mgrpath}.just.btn -side left
-   pack ${mgrpath}.rotate.tlab -side left
-   pack ${mgrpath}.rotate.tent -side right -fill x -expand true
-   pack ${mgrpath}.offset.tlab -side left
-   pack ${mgrpath}.offset.tent -side right -fill x -expand true
-   pack ${mgrpath}.buttonbar.apply -side left
-   pack ${mgrpath}.buttonbar.cancel -side right
-
-   pack ${mgrpath}.title -side top
-   pack ${mgrpath}.font -side top -anchor w
-   pack ${mgrpath}.text -side top -anchor w -expand true
-   pack ${mgrpath}.size -side top -anchor w -expand true
-   pack ${mgrpath}.just -side top -anchor w
-   pack ${mgrpath}.rotate -side top -anchor w -expand true
-   pack ${mgrpath}.offset -side top -anchor w -expand true
-   pack ${mgrpath}.buttonbar -side bottom -fill x -expand true
-}
-
-# Create or redisplay the text helper
-
-proc magic::texthelper {{option "update"}} {
-   global CAD_ROOT
-
-   if {[catch {wm state .texthelper}]} {
-      if {$option == "create"} {
-	 magic::maketexthelper .texthelper
-      } else {
-	 return
-      }
-   } elseif { $option == "create"} {
-      return
-   }
-
-   if {$option == "create"} {
-      menu .texthelper.just.btn.menu -tearoff 0
-      menu .texthelper.font.btn.menu -tearoff 0
-
-      .texthelper.just.btn.menu add command -label "NW" -command \
-		"magic::setlabel just nw ; \
-		 magic::texthelper update"
-      .texthelper.just.btn.menu add command -label "N" -command \
-		"magic::setlabel just n ; \
-		 magic::texthelper update"
-      .texthelper.just.btn.menu add command -label "NE" -command \
-		"magic::setlabel just ne ; \
-		 magic::texthelper update"
-      .texthelper.just.btn.menu add command -label "E" -command \
-		"magic::setlabel just e ; \
-		 magic::texthelper update"
-      .texthelper.just.btn.menu add command -label "SE" -command \
-		"magic::setlabel just se ; \
-		 magic::texthelper update"
-      .texthelper.just.btn.menu add command -label "S" -command \
-		"magic::setlabel just s ; \
-		 magic::texthelper update"
-      .texthelper.just.btn.menu add command -label "SW" -command \
-		"magic::setlabel just sw ; \
-		 magic::texthelper update"
-      .texthelper.just.btn.menu add command -label "W" -command \
-		"magic::setlabel just w ; \
-		 magic::texthelper update"
-      .texthelper.just.btn.menu add command -label "NW" -command \
-		"magic::setlabel just nw ; \
-		 magic::texthelper update"
-      .texthelper.just.btn.menu add command -label "center" -command \
-		"magic::setlabel just c ; \
-		 magic::texthelper update"
-   }
-
-   if {$option == "init"} {
-      .texthelper.font.btn.menu delete 0 end
-   }
-
-   if {$option ==  "init" || $option == "create"} {
-      set flist [magic::setlabel fontlist]
-      foreach i $flist {
-         .texthelper.font.btn.menu add command -label $i -command \
-		"magic::setlabel font $i ; \
-		 magic::texthelper update"
-      }
-   }
-}
-
-
 # Technology manager callback functions
 
 proc magic::techparseunits {} {
@@ -581,11 +294,18 @@ proc magic::maketechmanager { mgrpath } {
    bind ${mgrpath}.lambda1.lval0 <Return> magic::techparseunits
    bind ${mgrpath}.lambda1.lval1 <Return> magic::techparseunits
 
-   # Withdraw the window and unmark when the "close" button is pressed
-   wm protocol ${mgrpath} WM_DELETE_WINDOW "set Opts(techmgr) 0; \
-		wm withdraw ${mgrpath}"
+   #Withdraw the window when the close button is pressed
+   wm protocol ${mgrpath} WM_DELETE_WINDOW  "set Opts(techmgr) 0 ; wm withdraw ${mgrpath}"
 }
 
+# Generate the cell manager
+
+catch {source ${CAD_ROOT}/magic/tcl/cellmgr.tcl}
+
+# Generate the text helper
+
+catch {source ${CAD_ROOT}/magic/tcl/texthelper.tcl}
+
 # Create or redisplay the technology manager
 
 proc magic::techmanager {{option "update"}} {
@@ -717,8 +437,7 @@ proc magic::captions {{subcommand {}}} {
 # Note that the "box" tag doesn't apply to mouse-button events, so this function
 # is duplicated by Tk binding of mouse events in the layout window.
 
-magic::tag load "magic::cellmanager; magic::captions"
-magic::tag getcell "magic::cellmanager"
+magic::tag load "[magic::tag load]; magic::captions"
 magic::tag edit "magic::captions"
 magic::tag save "magic::captions"
 magic::tag down "magic::captions"
@@ -732,19 +451,13 @@ magic::tag see "magic::toolupdate %W %1 %2"
 magic::tag tech "magic::techrebuild %W %1; magic::captions %1"
 magic::tag drc "magic::drcupdate %1"
 magic::tag path "magic::techmanager update"
-if {$MagicBLT} {
-   magic::tag cellname "magic::mgrupdate %W %1"
-   magic::tag select "magic::mgrselect %R"
-   magic::tag cif "magic::mgrupdate %W %1"
-   magic::tag gds "magic::mgrupdate %W %1"
-} else {
-   magic::tag cellname "magic::captions %1"
-}
+magic::tag cellname "magic::mgrupdate %W %1"
+magic::tag cif      "magic::mgrupdate %W %1"
+magic::tag gds      "magic::mgrupdate %W %1"
 
 # This should be a list. . . do be done later
 set windowsopen 0
 
-set Opts(cellmgr) 0
 set Opts(techmgr) 0
 set Opts(target)  default
 set Opts(netlist) 0
@@ -753,6 +466,21 @@ set Opts(wind3d) 0
 set Opts(crosshair) 0
 set Opts(drc) 1
 
+# Update cell and tech managers in response to a cif or gds read command
+
+proc magic::mgrupdate {win {cmdstr ""}} {
+   if {${cmdstr} == "read"} {
+      catch {magic::cellmanager}
+      magic::captions
+      magic::techmanager update
+   } elseif {${cmdstr} == "delete" || ${cmdstr} == "rename"} {
+      catch {magic::cellmanager}
+      magic::captions
+   } elseif {${cmdstr} == "writeable"} {
+      magic::captions
+   }
+}
+
 # Set default width and height to be 3/4 of the screen size.
 set Opts(geometry) \
 "[expr 3 * [winfo screenwidth .] / 4]x[expr 3 * [winfo screenheight .] \
@@ -896,68 +624,6 @@ proc magic::toolupdate {win {yesno "yes"} {layerlist "none"}} {
    }
 }
 
-# Redirect and reformat Tcl output of "select" command
-
-if {$MagicBLT} {
-   proc magic::mgrselect {{sstr ""}} {
-      # Make sure we have a valid option, and the cell manager exists.
-      if {$sstr == ""} {
-	 return
-      } elseif {[catch {wm state .cellmgr}]} {
-	 return
-      }
-
-      set savetag [magic::tag select]
-      magic::tag select ""
-      .cellmgr.box.view selection clearall
-      if {[llength $sstr] == 5} {
-	 # sstr is "Topmost cell in the window"
-	 set clist [magic::cellname list window]
-	 set isrch [magic::cellname list instances $clist]
-	 foreach i $isrch {
-	    if {[llength $i] != 5} {
-	       set gsrch $i
-	       break
-	    } else {
-	       set gsrch $clist
-	    }
-         }
-         set idx [lindex [.cellmgr.box.view find -glob -full *${gsrch}*] 0]
-	 set cdef $clist
-      } else {
-	 regsub -all {\[.*\]} $sstr {[^a-z]+} newstr
-         set gsrch [string map {"/" " "} ".*${newstr}\$"]
-	 set cdef [magic::instance list celldef $sstr]
-         set idx [.cellmgr.box.view find -regexp -full "$gsrch"]
-      }
-      if {$idx != "" } {
-         .cellmgr.box.view open $idx
-         if {[wm state .cellmgr] == "normal"} { .cellmgr.box.view see $idx }
-         .cellmgr.box.view selection anchor $idx
-         .cellmgr.box.view selection set $idx
-         if {$sstr != ""} {
-	    puts stdout "Selected cell is $cdef ($sstr)"
-	 }
-      }
-      magic::tag select $savetag
-   }
-
-   # Update cell and tech managers in response to a cif or gds read command
-
-   proc magic::mgrupdate {win {cmdstr ""}} {
-      if {${cmdstr} == "read"} {
-	 magic::cellmanager
-	 magic::captions
-	 magic::techmanager update
-      } elseif {${cmdstr} == "delete" || ${cmdstr} == "rename"} {
-	 magic::cellmanager
-	 magic::captions
-      } elseif {${cmdstr} == "writeable"} {
-	 magic::captions
-      }
-   }
-}
-
 # Generate the toolbar for the wrapper
 
 proc magic::maketoolbar { framename } {
@@ -1231,7 +897,7 @@ proc magic::makescrollbar { fname orient win } {
 
 proc magic::openwrapper {{cell ""} {framename ""}} {
    global windowsopen
-   global MagicBLT
+   global tk_version
    global Glyph
    global Opts
    global Winopts
@@ -1375,7 +1041,7 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
    $m add command -label "Flip Vertical"   -command {magic::upsidedown}
    $m add separator
    $m add command -label "Text ..." \
-		-command [subst { magic::texthelper create; \
+		-command [subst { magic::update_texthelper; \
 		wm deiconify .texthelper ; raise .texthelper } ]
    $m add separator
    $m add command -label "Lock   Cell      " -command {magic::instance lock}
@@ -1418,15 +1084,15 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
 		grid forget ${framename}.toolbar } }]
 
    .winmenu add radio -label ${framename} -variable Opts(target) -value ${winname}
-   if {$MagicBLT} {
-      $m add check -label "Cell Manager" -variable Opts(cellmgr) \
-		-command [subst { magic::cellmanager create; \
-		if { \$Opts(cellmgr) } { \
-		wm deiconify .cellmgr ; raise .cellmgr \
-		} else { \
-		wm withdraw .cellmgr } }]
+   if {$tk_version >= 8.5} {
+     $m add check -label "Cell Manager" -variable Opts(cellmgr) \
+	-command [subst { magic::cellmanager create; \
+	if { \$Opts(cellmgr) } { \
+	   wm deiconify .cellmgr ; raise .cellmgr \
+	} else { \
+	   wm withdraw .cellmgr } }]
       .winmenu entryconfigure last -command ".cellmgr.target.list configure \
-		-text ${framename}"
+         -text ${framename}"
    }
 
    $m add check -label "Tech Manager" -variable Opts(techmgr) \
@@ -1472,9 +1138,6 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
 
    catch {addmazehelper $m}
 
-   # Update the cell manager (if it exists)
-   magic::cellmanager update
-
    # Set the default view
 
    update idletasks
@@ -1507,7 +1170,7 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
 # Delete the wrapper and the layout window in it.
 
 proc magic::closewrapper { framename } {
-   global MagicBLT
+   globa tk_version
    global Opts
 
    # Remove this window from the target list in .winmenu
@@ -1515,7 +1178,7 @@ proc magic::closewrapper { framename } {
 
    if { $Opts(target) == "${framename}.magic" } {
       set Opts(target) "default"
-      if {$MagicBLT} {
+      if {$tk_version >= 8.5} {
 	 if {![catch {wm state .cellmgr}]} {
 	    .cellmgr.target.list configure -text "default"
          } 
