@@ -19,7 +19,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/utils/getrect.c,v 1.2 2010/03/08 13:33:34 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/utils/getrect.c,v 1.3 2010/06/24 12:37:58 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -78,11 +78,7 @@ typedef unsigned char STDIOCHAR;
 
 #endif
 
-#ifdef NONMANHATTAN
 int
-#else
-bool
-#endif
 GetRect(fin, skip, rect, scalen, scaled)
     FILE *fin;
     int skip;			/* Number of bytes to skip before rect */
@@ -93,9 +89,7 @@ GetRect(fin, skip, rect, scalen, scaled)
     int n, c;
     char *cp;
     bool isNegative;
-#ifdef NONMANHATTAN
     int dir = 0x1;
-#endif
 
 #if !defined(__DragonFly__)
     if (FILE_CNT(fin) < RECTBUFTHRESHOLD) goto slow;
@@ -152,7 +146,6 @@ GetRect(fin, skip, rect, scalen, scaled)
 
     /* Make sure we skip to end of line or EOF */
     while (c != EOF && c != '\n')
-#ifdef NONMANHATTAN
     {
 	c = getc(fin);
 	switch ((char)c)
@@ -166,10 +159,6 @@ GetRect(fin, skip, rect, scalen, scaled)
 	}
     }
     return dir;
-#else
-	c = getc(fin);
-    return (TRUE);
-#endif 
 
     /* Adjust the stdio pointers to reflect the characters read */
 fastbad:
@@ -227,7 +216,6 @@ slow:
     }
 
     while (c != EOF && c != '\n')
-#ifdef NONMANHATTAN
     {
 	c = getc(fin);
 	switch ((char)c)
@@ -241,10 +229,6 @@ slow:
 	}
     }
     return dir;
-#else
-	c = getc(fin);
-    return (TRUE);
-#endif
 
 bad:
     while (c != EOF && c != '\n')
